import { Component, Inject, ChangeDetectorRef, EventEmitter, Output, Pipe, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialogConfig, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { Location, CommonModule } from '@angular/common';
import { Router } from '@angular/router';
import { UsersService, InteractionService, AuthenticationService, UsergroupService, InstitutionService, FormsService, MessagingService, LibServicesModule } from 'interfaceft-icb-lib-services/projects/lib-services/src/public-api';
import { NgxSpinnerService } from 'ngx-spinner';
import Swal from 'sweetalert2/dist/sweetalert2.js';
import { Validators, FormBuilder, FormControl, FormGroup, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { SearchCountryField, TooltipLabel, CountryISO, NgxIntlTelInputModule } from 'ngx-intl-tel-input';
import moment from 'moment';
import { v4 } from 'uuid';
import { Subject } from 'rxjs';
import { WebcamUtil, WebcamModule } from 'ngx-webcam';
import * as bcrypt from 'bcryptjs';
import { MatTableModule } from '@angular/material/table';
import { MatInputModule } from '@angular/material/input';
import { MatPaginatorModule } from '@angular/material/paginator';
import { HttpClientModule } from '@angular/common/http';
import { MatTableExporterModule } from 'mat-table-exporter';
import { MatSelectModule } from '@angular/material/select';
import { NgbModule } from '@ng-bootstrap/ng-bootstrap';
import { PdfViewerModule } from 'ng2-pdf-viewer';
import { ChartsModule } from 'ng2-charts';
import { AgmCoreModule } from '@agm/core';

class SignOutDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    ngOnInit() { }
    signout() {
        this.dialogRef.close(true);
    }
    close() {
        this.dialogRef.close(false);
    }
}
SignOutDialogComponent.decorators = [
    { type: Component, args: [{
                selector: "kt-sign-out-dialog",
                template: "<div class=\"card card-custom\" id=\"logout-dialog\">\n  <div\n    class=\"symbol symbol-danger mr-3 symbol-70 symbol-circle\"\n    id=\"logout-icon\"\n  >\n    <span class=\"symbol-label font-size-h5\">\n      <i style=\"font-size: 20px !important;\" class=\"fas fa-power-off text-white animate__animated animate__heartBeat animate__infinite\"></i>\n    </span>\n  </div>\n  <div class=\"card-body\">\n    <span class=\"font-weight-bolder d-block text-left mt-3 main-title\"\n      >ARE YOU SURE YOU WANT TO SIGN OUT?</span\n    >\n\n    <div class=\"d-flex justify-content-end\" style=\"margin-top: 50px\">\n      <button\n        (click)=\"close()\"\n        style=\"padding: 13px 21px\"\n        type=\"button\"\n        class=\"btn btn-outline-secondary mr-4 btn-square\"\n      >\n        <span>CANCEL</span>\n      </button>\n      <button\n        (click)=\"signout()\"\n        style=\"padding: 13px 21px\"\n        type=\"button\"\n        class=\"btn btn-danger btn-square\"\n      >\n        <span>SIGN OUT</span>\n      </button>\n    </div>\n  </div>\n</div>\n",
                styles: ["#logout-dialog{background-color:var(--background-color);color:#fff;border-radius:0;border-top:5px solid #dc143c;position:relative}#logout-icon{position:absolute;transform:translate(-50%,-50%);right:-35px;top:44px}.main-title{color:var(--text-color)!important}"]
            },] }
];
SignOutDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];

class ModuleNotFoundComponent {
    constructor(location) {
        this.location = location;
    }
    ngOnInit() { }
    goback() {
        this.location.back();
    }
}
ModuleNotFoundComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-module-not-found',
                template: "<div class=\"card card-custom module-card\">\n    <div class=\"card-body\">\n      <div class=\"row\">\n        <div class=\"col-7 text-center\">\n          <img\n            src=\"assets/images/defaults/404_page_not_found_.svg\"\n            style=\"width: 50%; margin: auto\"\n            alt=\"\"\n          />\n          <div\n            class=\"container d-flex flex-row-fluid flex-column justify-content-md-center p-6\"\n          >\n            <h1\n              class=\"error-title font-weight-boldest text-info mt-md-0\"\n              style=\"font-size: 75px\"\n            >\n              Oops!\n            </h1>\n            <p class=\"font-weight-boldest display-4 main-title\">Form Module Not Found!!!</p>\n            <p class=\"font-size-h3 main-title\">\n              Please Contact the Administrator for Additional Support\n            </p>\n            <a\n              style=\"width: 40%; margin: auto\"\n              (click)=\"goback()\"\n              class=\"btn btn-success font-weight-bold btn-pill btn-shadow px-10 py-3\"\n              >BACK TO DASHBOARD\n            </a>\n          </div>\n        </div>\n        <div class=\"col-5 d-flex\">\n          <img\n            src=\"assets/images/defaults/undraw_back_home_nl5c.svg\"\n            style=\"width: 100%\"\n            alt=\"\"\n          />\n        </div>\n      </div>\n    </div>\n  </div>",
                styles: [".module-card{background-color:var(--background-color)}"]
            },] }
];
ModuleNotFoundComponent.ctorParameters = () => [
    { type: Location }
];

class ConfirmDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
    }
    ngOnInit() { }
    confirm() {
        this.dialogRef.close('true');
    }
    cancel() {
        this.dialogRef.close('false');
    }
}
ConfirmDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-confirm-dialog',
                template: "<h1 mat-dialog-title style=\"padding: 11px 19px; text-align: center;\">Action Confirmation?</h1>\n<div mat-dialog-content style=\"padding: 10px 52px; text-align: center;\">\n  <h5 class=\"font-italic\">Please Confirm your Action</h5>\n</div>\n<div mat-dialog-actions style=\"padding: 0px 20px; display: flex; justify-content: center;\">\n  <a\n    (click)=\"cancel()\"\n    class=\"btn btn-light-danger font-weight-bold mr-2 py-3 px-4\"\n    >Cancel</a\n  >\n  <a\n  (click)=\"confirm()\"\n    class=\"btn btn-success font-weight-light mr-2 py-3 px-4\"\n    >Confirm</a\n  >\n</div>\n",
                styles: [""]
            },] }
];
ConfirmDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];

class ProfileDashboardComponent {
    constructor(cdr, dialog, userService, spinner, interactionservice, authservice, router) {
        this.cdr = cdr;
        this.dialog = dialog;
        this.userService = userService;
        this.spinner = spinner;
        this.interactionservice = interactionservice;
        this.authservice = authservice;
        this.router = router;
        this.bannerBg = 'assets/images/bg/starry-sky.jpg';
        this.profile = 'assets/images/profiles/default.jpg';
        this.loginDays = [];
        if (localStorage.getItem('institution')) {
            this.institution = JSON.parse(localStorage.getItem('institution'));
        }
        if (localStorage.getItem('currentuser')) {
            const details = JSON.parse(localStorage.getItem('currentuser'));
            this.userDetails = details['userdetails'];
            this.getimage();
            this.formatlogindays(this.userDetails);
        }
    }
    ngOnInit() {
        if (this.institution) {
            const bgimage = 'data:' +
                this.institution['backgroungimage1format'] +
                ';base64,' +
                this.institution['backgroungimage1base64'];
            this.bannerBg = bgimage;
        }
        this.interactionservice.componentMessage$.subscribe((data) => {
            if (data == 'reload_user') {
                this.fetchUserDetails();
            }
        });
        this.getRoute();
    }
    getRoute() {
        const urlArray = this.router.url.split('/');
        this.routeUrl = urlArray[1];
    }
    // fetch user loan Details
    fetchUserDetails() {
        this.interactionservice.loadMessage('LOADING ACCOUNT DETAILS');
        this.spinner.show();
        const sub = this.authservice
            .getCurrentUser(this.userDetails['username'])
            .subscribe((response) => {
            this.spinner.hide();
            this.cdr.markForCheck();
            if (response) {
                this.userDetails = response['userdetails'];
                localStorage.setItem('currentuser', JSON.stringify(response));
                this.formatlogindays(this.userDetails['userdetails']);
                sub.unsubscribe();
            }
        }, (error) => {
            this.alertWithError('USER ACCOUNT', error.message);
            this.spinner.hide();
            this.cdr.markForCheck();
            sub.unsubscribe();
        });
    }
    formatlogindays(userDetails) {
        if (userDetails) {
            this.loginDays = userDetails.daysallowed.split(',');
            this.cdr.markForCheck();
        }
    }
    getimage() {
        if (this.userDetails) {
            if (this.userDetails.pictureformat) {
                this.profile =
                    'data:' +
                        this.userDetails.pictureformat +
                        ';base64,' +
                        this.userDetails.picture;
            }
            else {
                this.profile = 'data:image/png;base64,' + this.userDetails.picture;
            }
        }
    }
    trackByMethod(index, el) {
        return index;
    }
    editUser() {
        const accounturl = '/' + this.routeUrl + '/' + 'my_account/edit';
        console.log(accounturl);
        this.router.navigate([accounturl]);
    }
    forgetPassword() {
        const dialogConfig = new MatDialogConfig();
        dialogConfig.panelClass = 'newPasswordDialog';
        const dialogResponse = this.dialog.open(ConfirmDialogComponent, dialogConfig);
        dialogResponse.afterClosed().subscribe((result) => {
            if (result === 'true') {
                this.initializePasswordReset();
            }
            else {
                return;
            }
        });
    }
    initializePasswordReset() {
        this.interactionservice.loadMessage('WE ARE RESETTING YOUR PASSWORD, PLEASE WAIT...');
        this.spinner.show();
        const sub = this.userService
            .resetPasswordPIN(this.userDetails.id, 'PASSWORD')
            .subscribe((data) => {
            this.spinner.hide();
            if (data['code'] === '200') {
                this.ngOnInit();
                this.alertWithSuccess('RESET PASSWORD', 'AN EMAIL WILL BE SENT TO YOU SHORTLY');
            }
            else if (data['code'] === '-1') {
                this.alertWithError('RESET PASSWORD', data['description']);
            }
            sub.unsubscribe();
        }, (error) => {
            this.spinner.hide();
            this.alertWithError('RESET PASSWORD', error['error']['error_description']);
            sub.unsubscribe();
        });
    }
    forgetPIN() {
        const dialogConfig = new MatDialogConfig();
        dialogConfig.panelClass = 'newPasswordDialog';
        const dialogResponse = this.dialog.open(ConfirmDialogComponent, dialogConfig);
        dialogResponse.afterClosed().subscribe((result) => {
            if (result === 'true') {
                this.initializePinReset();
            }
            else {
                return;
            }
        });
    }
    // initialize pin reset process
    initializePinReset() {
        this.interactionservice.loadMessage('WE ARE RESETTING YOUR PIN, PLEASE WAIT...');
        this.spinner.show();
        const sub = this.userService
            .resetPasswordPIN(this.userDetails.id, 'PIN')
            .subscribe((data) => {
            this.spinner.hide();
            if (data['code'] === '200') {
                this.interactionservice.sendMessage('reloadUserAccounts');
                this.alertWithSuccess('RESET PIN', 'AN EMAIL WILL BE SENT TO YOU SHORTLY');
            }
            else if (data['code'] === '-1') {
                this.alertWithError('RESET PIN', data['description']);
            }
            sub.unsubscribe();
        }, (error) => {
            this.spinner.hide();
            this.alertWithError('RESET PIN', error['error']['error_description']);
            sub.unsubscribe();
        });
    }
    deactivateUser() {
        const dialogConfig = new MatDialogConfig();
        dialogConfig.panelClass = 'newPasswordDialog';
        const dialogResponse = this.dialog.open(ConfirmDialogComponent, dialogConfig);
        dialogResponse.afterClosed().subscribe((result) => {
            if (result === 'true') {
                this.initializeDeactivation();
            }
            else {
                return;
            }
        });
    }
    // initialize deactivation
    initializeDeactivation() {
        this.interactionservice.loadMessage('WE ARE DEACTIVATING YOUR ACCOUNT, PLEASE WAIT...');
        this.spinner.show();
        const sub = this.userService.deactivateUser(this.userDetails.id).subscribe((data) => {
            this.spinner.hide();
            if (data['code'] === '200') {
                this.alertWithSuccess('USER ACCOUNT', 'USER DEACTIVATED');
                this.router.navigate(['/dashboard']);
            }
            else if (data['code'] === '-1') {
                this.alertWithError('USER ACCOUNT', data['description']);
            }
            sub.unsubscribe();
        }, (error) => {
            this.spinner.hide();
            this.alertWithError('USER ACCOUNT', error['error']['error_description']);
            sub.unsubscribe();
        });
    }
    activateUser() {
        const dialogConfig = new MatDialogConfig();
        dialogConfig.panelClass = 'newPasswordDialog';
        const dialogResponse = this.dialog.open(ConfirmDialogComponent, dialogConfig);
        dialogResponse.afterClosed().subscribe((result) => {
            if (result === 'true') {
                this.initializeActivation();
            }
            else {
                return;
            }
        });
    }
    // initialize activation
    initializeActivation() {
        this.interactionservice.loadMessage('WE ARE ACTIVATING YOUR ACCOUNT, PLEASE WAIT...');
        this.spinner.show();
        const sub = this.userService.activateUser(this.userDetails.id).subscribe((data) => {
            this.spinner.hide();
            if (data['code'] === '200') {
                this.alertWithSuccess('USER ACCOUNT', 'USER ACTIVATED');
                this.router.navigate(['/dashboard']);
            }
            else if (data['code'] === '-1') {
                this.alertWithError('USER ACCOUNT', data['description']);
            }
            sub.unsubscribe();
        }, (error) => {
            this.spinner.hide();
            this.alertWithError('USER ACCOUNT', error['error']['error_description']);
            sub.unsubscribe();
        });
    }
    alertWithSuccess(title, message) {
        Swal.fire({
            icon: 'success',
            title: title,
            text: message,
        });
    }
    alertWithError(title, message) {
        Swal.fire({
            icon: 'error',
            title: title,
            text: message,
        });
    }
}
ProfileDashboardComponent.decorators = [
    { type: Component, args: [{
                selector: 'authdashboard-profile-dashboard',
                template: "<div class=\"container-fluid\">\n  <div\n    class=\"profile-banner-bg\"\n    [ngStyle]=\"{ 'background-image': 'url(' + bannerBg + ')' }\"\n  ></div>\n  <div class=\"container\" style=\"position: relative; top: -80px\">\n    <div class=\"row\">\n      <div class=\"col-lg-4 col-12\">\n        <div class=\"card card-custom module-card\">\n          <div class=\"card-body\">\n            <div class=\"text-center\">\n              <div class=\"symbol symbol-circle symbol-100 mr-3\">\n                <img alt=\"Pic\" [src]=\"profile\" />\n                <i\n                  class=\"symbol-badge bg-primary\"\n                  *ngIf=\"userDetails?.enabled\"\n                ></i>\n                <i\n                  class=\"symbol-badge bg-danger\"\n                  *ngIf=\"!userDetails?.enabled\"\n                ></i>\n              </div>\n            </div>\n            <span class=\"font-weight-bold d-block text-center mt-3 main-title\"\n              >{{ userDetails?.firstname }} {{ userDetails?.lastname }}</span\n            >\n            <span\n              class=\"font-weight-bold d-block text-muted text-center mt-2\"\n              >{{ userDetails?.email }}</span\n            >\n            <div class=\"text-center mt-2\">\n              <span class=\"font-weight-bold text-muted text-center mr-4\"\n                >Username: {{ userDetails?.username }}</span\n              >\n              <span class=\"font-weight-bold text-muted text-center\"\n                >Status:\n                {{ userDetails?.enabled ? \"Active\" : \"Inactive\" }}</span\n              >\n            </div>\n\n            <div class=\"card mt-3 btns-card\" style=\"border: 1px solid #ececec\">\n              <div class=\"card-body\">\n                <button\n                  (click)=\"editUser()\"\n                  type=\"button\"\n                  class=\"btn btn-primary btn-lg btn-block mb-2 user-account-btn\"\n                >\n                  <span style=\"font-size: 12px\">Edit Account</span>\n                </button>\n\n                <button\n                  (click)=\"forgetPassword()\"\n                  type=\"button\"\n                  class=\"btn btn-info btn-lg btn-block mb-2 user-account-btn\"\n                >\n                  <span style=\"font-size: 12px\">Reset Password</span>\n                </button>\n\n                <button\n                  (click)=\"forgetPIN()\"\n                  type=\"button\"\n                  class=\"btn btn-info btn-lg btn-block mb-2 user-account-btn\"\n                >\n                  <span style=\"font-size: 12px\">Reset Pin</span>\n                </button>\n\n                <button\n                  *ngIf=\"userDetails?.enabled\"\n                  (click)=\"deactivateUser()\"\n                  type=\"button\"\n                  class=\"btn btn-danger btn-lg btn-block mb-2 user-account-btn\"\n                >\n                  <span style=\"font-size: 12px\">Deactivate Account</span>\n                </button>\n\n                <button\n                  *ngIf=\"!userDetails?.enabled\"\n                  (click)=\"activateUser()\"\n                  type=\"button\"\n                  class=\"btn btn-danger btn-lg btn-block mb-2 user-account-btn\"\n                >\n                  <span style=\"font-size: 12px\">Deactivate Account</span>\n                </button>\n              </div>\n            </div>\n          </div>\n        </div>\n      </div>\n      <div class=\"col-lg-8 col-12\">\n        <div class=\"card card-custom module-card\">\n          <div class=\"card-header card-header-tabs-line\">\n            <div class=\"card-toolbar\">\n              <ul class=\"nav nav-tabs nav-bold nav-tabs-line\">\n                <li class=\"nav-item\">\n                  <a\n                    class=\"nav-link active main-title\"\n                    data-toggle=\"tab\"\n                    href=\"#kt_tab_pane_1_2\"\n                    >Overview</a\n                  >\n                </li>\n                <li class=\"nav-item\">\n                  <a\n                    class=\"nav-link main-title\"\n                    data-toggle=\"tab\"\n                    href=\"#kt_tab_pane_3_2\"\n                    >Login Days</a\n                  >\n                </li>\n              </ul>\n            </div>\n          </div>\n          <div class=\"card-body\">\n            <div class=\"tab-content\">\n              <div\n                class=\"tab-pane fade show active\"\n                id=\"kt_tab_pane_1_2\"\n                role=\"tabpanel\"\n              >\n                <div class=\"row\">\n                  <div class=\"col-lg-4 col-sm-6 col-12\">\n                    <div class=\"other-personal-info-summary\">\n                      <div\n                        class=\"d-flex justify-content-between align-content-center mb-3\"\n                      >\n                        <span class=\"font-weight-bold d-block mr-10 main-title\"\n                          >Created Date</span\n                        >\n                        <span class=\"font-weight-bold text-muted d-block\">{{\n                          userDetails?.createddate ? userDetails?.createddate : 'not available'\n                        }}</span>\n                      </div>\n\n                      <div\n                        class=\"d-flex justify-content-between align-content-center mb-3\"\n                      >\n                        <span class=\"font-weight-bold d-block mr-10 main-title\"\n                          >Contact</span\n                        >\n                        <span class=\"font-weight-bold text-muted d-block\">{{\n                          userDetails?.phonenumber\n                        }}</span>\n                      </div>\n\n                      <div\n                        class=\"d-flex justify-content-between align-content-center mb-3\"\n                      >\n                        <span class=\"font-weight-bold d-block mr-10 main-title\"\n                          >Branch</span\n                        >\n                        <span class=\"font-weight-bold text-muted d-block\">{{\n                          userDetails?.branchname\n                        }}</span>\n                      </div>\n\n                      <div\n                        class=\"d-flex justify-content-between align-content-center mb-3\"\n                      >\n                        <span class=\"font-weight-bold d-block mr-10 main-title\"\n                          >Filter Mode</span\n                        >\n                        <span class=\"font-weight-bold text-muted d-block\">{{\n                          userDetails?.filtermode\n                        }}</span>\n                      </div>\n\n                      <div\n                        class=\"d-flex justify-content-between align-content-center\"\n                      >\n                        <span class=\"font-weight-bold d-block mr-10 main-title\"\n                          >User Group</span\n                        >\n                        <span\n                          class=\"label label-primary label-inline font-weight-lighter ml-2 p-2 d-flex\"\n                          >{{ userDetails?.usergroupid }}</span\n                        >\n                      </div>\n                    </div>\n                  </div>\n                  <div class=\"col-lg-4 col-sm-6 col-12\">\n                    <div class=\"ml-20\">\n                      <div\n                        class=\"d-flex justify-content-between align-content-center mb-3\"\n                      >\n                        <span class=\"font-weight-bold d-block mr-10 main-title\"\n                          >Agency</span\n                        >\n                        <span class=\"font-weight-bold text-muted d-block\">{{\n                          userDetails?.agencycode\n                        }}</span>\n                      </div>\n\n                      <div\n                        class=\"d-flex justify-content-between align-content-center mb-3\"\n                      >\n                        <span class=\"font-weight-bold d-block mr-10 main-title\"\n                          >Login From</span\n                        >\n                        <span class=\"font-weight-bold text-muted d-block\">{{\n                          userDetails?.loginfrom\n                        }}</span>\n                      </div>\n\n                      <div\n                        class=\"d-flex justify-content-between align-content-center\"\n                      >\n                        <span class=\"font-weight-bold d-block mr-10 main-title\"\n                          >Login To</span\n                        >\n                        <span class=\"font-weight-bold text-muted d-block\">{{\n                          userDetails?.loginto\n                        }}</span>\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </div>\n              <div class=\"tab-pane fade\" id=\"kt_tab_pane_3_2\" role=\"tabpanel\">\n                <div class=\"card-body\">\n                  <ng-container *ngIf=\"loginDays.length\">\n                    <ng-container\n                      *ngFor=\"\n                        let day of loginDays;\n                        let i = index;\n                        trackBy: trackByMethod\n                      \"\n                    >\n                      <div [ngSwitch]=\"day\">\n                        <div *ngSwitchCase=\"'MONDAY'\">\n                          <!--begin::Item-->\n                          <div class=\"d-flex align-items-center mb-4\">\n                            <!--begin::Bullet-->\n                            <span\n                              class=\"bullet bullet-bar bg-success align-self-stretch\"\n                            ></span>\n                            <!--end::Bullet-->\n\n                            <!--begin::Checkbox-->\n                            <label\n                              class=\"checkbox checkbox-lg checkbox-light-success checkbox-inline flex-shrink-0 m-0 mx-4\"\n                            >\n                              <input\n                                type=\"checkbox\"\n                                name=\"select\"\n                                checked\n                                value=\"1\"\n                                disabled\n                              />\n                              <span></span>\n                            </label>\n                            <!--end::Checkbox-->\n\n                            <!--begin::Text-->\n                            <div class=\"d-flex flex-column flex-grow-1\">\n                              <a\n                                href=\"#\"\n                                class=\"main-title text-hover-primary font-weight-bold font-size-lg mb-1\"\n                              >\n                                MONDAY\n                              </a>\n                            </div>\n                            <!--end::Text-->\n                          </div>\n                          <!--end:Item-->\n                        </div>\n                        <div *ngSwitchCase=\"'TUESDAY'\">\n                          <!--begin::Item-->\n                          <div class=\"d-flex align-items-center mb-4\">\n                            <!--begin::Bullet-->\n                            <span\n                              class=\"bullet bullet-bar bg-primary align-self-stretch\"\n                            ></span>\n                            <!--end::Bullet-->\n\n                            <!--begin::Checkbox-->\n                            <label\n                              class=\"checkbox checkbox-lg checkbox-light-primary checkbox-inline flex-shrink-0 m-0 mx-4\"\n                            >\n                              <input\n                                type=\"checkbox\"\n                                name=\"select\"\n                                checked\n                                value=\"1\"\n                                disabled\n                              />\n                              <span></span>\n                            </label>\n                            <!--end::Checkbox-->\n\n                            <!--begin::Text-->\n                            <div class=\"d-flex flex-column flex-grow-1\">\n                              <a\n                                href=\"#\"\n                                class=\"main-title text-hover-primary font-weight-bold font-size-lg mb-1\"\n                              >\n                                TUESDAY\n                              </a>\n                            </div>\n                            <!--end::Text-->\n                          </div>\n                          <!--end:Item-->\n                        </div>\n                        <div *ngSwitchCase=\"'WEDNESDAY'\">\n                          <!--begin::Item-->\n                          <div class=\"d-flex align-items-center mb-4\">\n                            <!--begin::Bullet-->\n                            <span\n                              class=\"bullet bullet-bar bg-warning align-self-stretch\"\n                            ></span>\n                            <!--end::Bullet-->\n\n                            <!--begin::Checkbox-->\n                            <label\n                              class=\"checkbox checkbox-lg checkbox-light-warning checkbox-inline flex-shrink-0 m-0 mx-4\"\n                            >\n                              <input\n                                type=\"checkbox\"\n                                name=\"select\"\n                                checked\n                                value=\"1\"\n                                disabled\n                              />\n                              <span></span>\n                            </label>\n                            <!--end::Checkbox-->\n\n                            <!--begin::Text-->\n                            <div class=\"d-flex flex-column flex-grow-1\">\n                              <a\n                                href=\"#\"\n                                class=\"main-title text-hover-primary font-weight-bold font-size-lg mb-1\"\n                              >\n                                WEDNESDAY\n                              </a>\n                            </div>\n                            <!--end::Text-->\n                          </div>\n                          <!--end:Item-->\n                        </div>\n\n                        <div *ngSwitchCase=\"'THURSDAY'\">\n                          <!--begin::Item-->\n                          <div class=\"d-flex align-items-center mb-4\">\n                            <!--begin::Bullet-->\n                            <span\n                              class=\"bullet bullet-bar bg-success align-self-stretch\"\n                            ></span>\n                            <!--end::Bullet-->\n\n                            <!--begin::Checkbox-->\n                            <label\n                              class=\"checkbox checkbox-lg checkbox-light-success checkbox-inline flex-shrink-0 m-0 mx-4\"\n                            >\n                              <input\n                                type=\"checkbox\"\n                                name=\"select\"\n                                checked\n                                value=\"1\"\n                                disabled\n                              />\n                              <span></span>\n                            </label>\n                            <!--end::Checkbox-->\n\n                            <!--begin::Text-->\n                            <div class=\"d-flex flex-column flex-grow-1\">\n                              <a\n                                href=\"#\"\n                                class=\"main-title text-hover-primary font-weight-bold font-size-lg mb-1\"\n                              >\n                                THURSDAY\n                              </a>\n                            </div>\n                            <!--end::Text-->\n                          </div>\n                          <!--end:Item-->\n                        </div>\n\n                        <div *ngSwitchCase=\"'FRIDAY'\">\n                          <!--begin::Item-->\n                          <div class=\"d-flex align-items-center mb-4\">\n                            <!--begin::Bullet-->\n                            <span\n                              class=\"bullet bullet-bar bg-danger align-self-stretch\"\n                            ></span>\n                            <!--end::Bullet-->\n\n                            <!--begin::Checkbox-->\n                            <label\n                              class=\"checkbox checkbox-lg checkbox-light-danger checkbox-inline flex-shrink-0 m-0 mx-4\"\n                            >\n                              <input\n                                type=\"checkbox\"\n                                name=\"select\"\n                                checked\n                                value=\"1\"\n                                disabled\n                              />\n                              <span></span>\n                            </label>\n                            <!--end::Checkbox-->\n\n                            <!--begin::Text-->\n                            <div class=\"d-flex flex-column flex-grow-1\">\n                              <a\n                                href=\"#\"\n                                class=\"main-title text-hover-primary font-weight-bold font-size-lg mb-1\"\n                              >\n                                FRIDAY\n                              </a>\n                            </div>\n                            <!--end::Text-->\n                          </div>\n                          <!--end:Item-->\n                        </div>\n\n                        <div *ngSwitchCase=\"'SATURDAY'\">\n                          <!--begin::Item-->\n                          <div class=\"d-flex align-items-center mb-4\">\n                            <!--begin::Bullet-->\n                            <span\n                              class=\"bullet bullet-bar bg-info align-self-stretch\"\n                            ></span>\n                            <!--end::Bullet-->\n\n                            <!--begin::Checkbox-->\n                            <label\n                              class=\"checkbox checkbox-lg checkbox-light-info checkbox-inline flex-shrink-0 m-0 mx-4\"\n                            >\n                              <input\n                                type=\"checkbox\"\n                                name=\"select\"\n                                checked\n                                value=\"1\"\n                                disabled\n                              />\n                              <span></span>\n                            </label>\n                            <!--end::Checkbox-->\n\n                            <!--begin::Text-->\n                            <div class=\"d-flex flex-column flex-grow-1\">\n                              <a\n                                href=\"#\"\n                                class=\"main-title text-hover-primary font-weight-bold font-size-lg mb-1\"\n                              >\n                                SATURDAY\n                              </a>\n                            </div>\n                            <!--end::Text-->\n                          </div>\n                          <!--end:Item-->\n                        </div>\n                        <div *ngSwitchCase=\"'SUNDAY'\">\n                          <!--begin::Item-->\n                          <div class=\"d-flex align-items-center mb-5\">\n                            <!--begin::Bullet-->\n                            <span\n                              class=\"bullet bullet-bar bg-success align-self-stretch\"\n                            ></span>\n                            <!--end::Bullet-->\n\n                            <!--begin::Checkbox-->\n                            <label\n                              class=\"checkbox checkbox-lg checkbox-light-success checkbox-inline flex-shrink-0 m-0 mx-4\"\n                            >\n                              <input\n                                type=\"checkbox\"\n                                name=\"select\"\n                                checked\n                                value=\"1\"\n                                disabled\n                              />\n                              <span></span>\n                            </label>\n                            <!--end::Checkbox-->\n\n                            <!--begin::Text-->\n                            <div class=\"d-flex flex-column flex-grow-1\">\n                              <a\n                                href=\"#\"\n                                class=\"main-title text-hover-primary font-weight-bold font-size-lg mb-1\"\n                              >\n                                SUNDAY\n                              </a>\n                            </div>\n                            <!--end::Text-->\n                          </div>\n                          <!--end:Item-->\n                        </div>\n                      </div>\n                    </ng-container>\n                  </ng-container>\n                </div>\n              </div>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n  </div>\n</div>\n",
                styles: [".profile-banner-bg{width:100%;height:300px;background-position:50%;background-size:cover;background-repeat:no-repeat;position:relative}.profile-banner-bg:after{content:\"\";position:absolute;top:0;left:0;width:100%;height:inherit;background-color:#067eed;opacity:.7}.btns-card{border:1px solid var(--border-color);transition:.5s}.btns-card,.module-card{background-color:var(--background-color)}.module-card{box-shadow:0 1px 20px 0 rgba(0,0,0,.1)!important;border-radius:10px}.module-card i{color:#ff7c1f!important}.user-account-btn{border-radius:30px;padding:10px;margin-bottom:18px!important}"]
            },] }
];
ProfileDashboardComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: MatDialog },
    { type: UsersService },
    { type: NgxSpinnerService },
    { type: InteractionService },
    { type: AuthenticationService },
    { type: Router }
];

const ɵ0$3 = (toast) => {
    toast.addEventListener('mouseenter', Swal.stopTimer);
    toast.addEventListener('mouseleave', Swal.resumeTimer);
};
const Toast$3 = Swal.mixin({
    toast: true,
    position: 'top-end',
    showConfirmButton: false,
    timer: 3000,
    timerProgressBar: true,
    didOpen: ɵ0$3,
});
class EditAccountProfileFormComponent {
    constructor(formBuilder, usergroupService, institutionService, authService, userService, dialog, cdr, router, spinner, interactionService, location) {
        var _a;
        this.formBuilder = formBuilder;
        this.usergroupService = usergroupService;
        this.institutionService = institutionService;
        this.authService = authService;
        this.userService = userService;
        this.dialog = dialog;
        this.cdr = cdr;
        this.router = router;
        this.spinner = spinner;
        this.interactionService = interactionService;
        this.location = location;
        // International Telephone
        this.separateDialCode = true;
        this.SearchCountryField = SearchCountryField;
        this.TooltipLabel = TooltipLabel;
        this.CountryISO = CountryISO;
        this.days = [
            'MONDAY',
            'TUESDAY',
            'WEDNESDAY',
            'THURSDAY',
            'FRIDAY',
            'SATURDAY',
            'SUNDAY',
        ];
        this.emailValid = false;
        this.usernameValid = false;
        this.contactValid = false;
        this.loginDaysError = false;
        this.permission = false;
        if (localStorage.getItem('institution')) {
            this.institution = JSON.parse(localStorage.getItem('institution'));
            this.institutionCountry =
                CountryISO[this.titleCase((_a = this.institution) === null || _a === void 0 ? void 0 : _a.country)];
            this.cdr.markForCheck();
        }
        if (localStorage.getItem('dictionaries')) {
            const dictionaries = JSON.parse(localStorage.getItem('dictionaries'));
            this.mfaTypes = dictionaries['mfa_types'];
        }
        if (localStorage.getItem('currentuser')) {
            const details = JSON.parse(localStorage.getItem('currentuser'));
            this.userDetails = details['userdetails'];
        }
        if (localStorage.getItem('userpermissions')) {
            this.userpermissions = JSON.parse(localStorage.getItem('userpermissions'));
        }
        this.DaysAllowed = this.formBuilder.group({
            dayselected: ['', Validators.required],
        });
        this.Form = this.formBuilder.group({
            firstname: ['', Validators.required],
            middlename: [''],
            lastname: ['', Validators.required],
            email: ['', [Validators.required, Validators.email]],
            username: ['', Validators.required],
            filtermode: [, Validators.required],
            daysallowed: [''],
            phonenumber: ['', Validators.required],
            usergroupid: ['', Validators.required],
            branchcode: ['', Validators.required],
            branchname: [''],
            agencycode: ['', Validators.required],
            loginfrom: [''],
            loginto: [''],
            allowotp: [''],
            ipaddressvalue: [''],
            restrictipaddress: [],
        });
    }
    ngOnInit() {
        this.populateform();
        this.setDaysAllowed();
        this.fetchBranches();
        this.getUserGroups();
        this.setIPADDRESSValidations();
        this.fetchAgency();
    }
    // fetch branches
    fetchBranches() {
        const sub = this.institutionService.getAllBranches().subscribe((data) => {
            this.branches = data;
            sub.unsubscribe();
        }, (error) => {
            sub.unsubscribe();
        });
    }
    // fetch User groups
    getUserGroups() {
        const sub = this.usergroupService.getAllUserGroup().subscribe((data) => {
            this.usergroups = data;
            sub.unsubscribe();
        }, (error) => {
            sub.unsubscribe();
        });
    }
    populateform() {
        // getting loginfrom and loginto date
        const loginfrom = this.userDetails.loginfrom.split(':');
        const loginto = this.userDetails.loginto.split(':');
        const dateFrom = new Date();
        const dateTo = new Date();
        let fromMinutes = loginfrom[1] ? loginfrom[1] : '00';
        dateFrom.setHours(loginfrom[0]);
        dateFrom.setMinutes(fromMinutes);
        dateTo.setHours(loginto[0]);
        dateTo.setMinutes(loginto[1]);
        const fromFormat = moment(dateFrom).format('HH:mm');
        const toFormat = moment(dateTo).format('HH:mm');
        this.filtermode = this.authService.userFilterMode();
        this.Form.patchValue({
            firstname: this.userDetails.firstname,
            middlename: this.userDetails.middlename,
            lastname: this.userDetails.lastname,
            email: this.userDetails.email,
            username: this.userDetails.username,
            filtermode: this.userDetails.filtermode,
            daysallowed: [''],
            phonenumber: this.userDetails.phonenumber,
            usergroupid: this.userDetails.usergroupid,
            branchcode: this.userDetails.branchcode,
            branchname: this.userDetails.branchname,
            agencycode: this.userDetails.agencycode,
            loginfrom: fromFormat,
            loginto: toFormat,
            allowotp: this.userDetails.allowotp,
            ipaddressvalue: this.userDetails.ipadressvalue,
            restrictipaddress: this.userDetails.restrictipaddress,
        });
    }
    setDaysAllowed() {
        this.Form.patchValue({
            daysallowed: this.userDetails.daysallowed.split(','),
        });
    }
    getpermissions() {
        this.userService.getUserMenuPermission(this.userDetails.username).subscribe((data) => {
            localStorage.setItem('userpermissions', JSON.stringify(data));
        }, (error) => {
            console.log(error);
        });
    }
    // convert strings to titlecase
    titleCase(str) {
        if (str === null || str === '')
            return false;
        else
            str = str.toString();
        return str.replace(/\w\S*/g, function (txt) {
            return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
        });
    }
    fetchAgency() {
        if (this.Form.get('branchcode').value) {
            this.getBranchAgency(this.Form.get('branchcode').value);
            this.cdr.markForCheck();
        }
    }
    // fetch branch agency
    getBranchAgency(branchcode) {
        this.Form.get('agencycode').setValue('');
        const sub = this.institutionService.getBranchAgency(branchcode).subscribe((data) => {
            this.agencies = data;
            if (data) {
                if (data[0]) {
                    if (data[0]['code']) {
                        this.Form.get('agencycode').setValue(data[0]['code']);
                    }
                }
            }
            sub.unsubscribe();
        }, (error) => {
            sub.unsubscribe();
        });
    }
    // validate Username if its exist
    isUsernameUnique(control) {
        clearTimeout(this.debouncer4);
        if (control.value) {
            const q = new Promise((resolve, reject) => {
                this.debouncer4 = setTimeout(() => {
                    var sub = this.userService.validateUsername(control.value).subscribe((data2) => {
                        if (data2['isUsed']) {
                            this.Form.controls['username'].setErrors({
                                isUsed: true,
                            });
                            resolve(data2);
                        }
                        else {
                            resolve(null);
                            this.Form.controls['username'].setErrors(null);
                        }
                        sub.unsubscribe();
                    }, (error2) => {
                        resolve(null);
                        sub.unsubscribe();
                    });
                }, 1000);
            });
            return q;
        }
        else {
            const q = new Promise((resolve, reject) => {
                resolve(null);
            });
            return q;
        }
    }
    // validate Email if its exist
    isEmailUnique(control) {
        clearTimeout(this.debouncer2);
        if (control.value) {
            const q = new Promise((resolve, reject) => {
                this.debouncer2 = setTimeout(() => {
                    var sub = this.userService.validateEmail(control.value).subscribe((data2) => {
                        if (data2['isUsed']) {
                            this.Form.controls['email'].setErrors({
                                isUsed: true,
                            });
                            resolve(data2);
                        }
                        else {
                            resolve(null);
                            this.Form.controls['email'].setErrors(null);
                        }
                        sub.unsubscribe();
                    }, (error2) => {
                        resolve(null);
                        sub.unsubscribe();
                    });
                }, 1000);
            });
            return q;
        }
        else {
            const q = new Promise((resolve, reject) => {
                resolve(null);
            });
            return q;
        }
    }
    // validate Phone number if its exist
    isPhoneUnique(control) {
        clearTimeout(this.debouncer1);
        if (control.value) {
            const q = new Promise((resolve, reject) => {
                this.debouncer1 = setTimeout(() => {
                    var sub = this.userService
                        .validatePhonenumber(control.value)
                        .subscribe((data2) => {
                        if (data2['isUsed']) {
                            this.Form.controls['phonenumber'].setErrors({
                                isUsed: true,
                            });
                            resolve(data2);
                        }
                        else {
                            resolve(null);
                            this.Form.controls['phonenumber'].setErrors(null);
                        }
                        sub.unsubscribe();
                    }, (error2) => {
                        resolve(null);
                        sub.unsubscribe();
                    });
                }, 1000);
            });
            return q;
        }
        else {
            const q = new Promise((resolve, reject) => {
                resolve(null);
            });
            return q;
        }
    }
    // set IPADDRESSTYPE validations
    setIPADDRESSValidations() {
        const ipAddressvalue = this.Form.get('ipAddressvalue');
        this.Form.controls['restrictipaddress'].valueChanges.subscribe((value) => {
            if (value === 'true') {
                ipAddressvalue.setValidators([Validators.required]);
            }
            else if (value === 'false') {
                ipAddressvalue.setValidators(null);
            }
        });
    }
    // on branch change
    branchChange(event) {
        const branch = this.branches.find((item) => item.branchcode === event.target.value);
        this.Form.get('branchname').setValue(branch.name);
        this.getBranchAgency(event.target.value);
    }
    // toggle permission module event
    setModuleEvent(event, appeventid) {
        if (this.userDetails.username) {
            this.loadingMessage = 'Updating Permission...';
            this.spinner.show();
            const value = event.target.checked;
            const sub = this.userService
                .setUserMenu(this.userDetails.username, appeventid, value)
                .subscribe((data) => {
                if (data['code'] == '200') {
                    Toast$3.fire({
                        icon: 'success',
                        title: 'PERMISSION UPDATED',
                    });
                }
                this.spinner.hide();
                this.cdr.markForCheck();
                console.log(data);
                sub.unsubscribe();
            }, (error) => {
                Toast$3.fire({
                    icon: 'error',
                    title: error.message,
                });
                this.spinner.hide();
                this.cdr.markForCheck();
                sub.unsubscribe();
            });
        }
    }
    // toggle permission event
    setEvent(event, appeventid) {
        if (this.userDetails.username) {
            this.loadingMessage = 'Updating Permission...';
            this.spinner.show();
            const value = event.target.checked;
            const sub = this.userService
                .setUserEventPermission(this.userDetails.username, appeventid, value)
                .subscribe((data) => {
                if (data['code'] == '200') {
                    Toast$3.fire({
                        icon: 'success',
                        title: 'PERMISSION UPDATED',
                    });
                }
                this.spinner.hide();
                this.cdr.markForCheck();
                console.log(data);
                sub.unsubscribe();
            }, (error) => {
                Toast$3.fire({
                    icon: 'error',
                    title: error.message,
                });
                this.spinner.hide();
                this.cdr.markForCheck();
                sub.unsubscribe();
            });
        }
    }
    alertWithSuccess(title, message) {
        Swal.fire({
            icon: 'success',
            title: title,
            text: message,
        });
    }
    alertWithError(title, message) {
        Swal.fire({
            icon: 'error',
            title: title,
            text: message,
        });
    }
    update() {
        if (this.Form.valid) {
            this.confirmDialog();
        }
        else {
            this.alertWithError('USER ACCOUNT', 'INVALID FORM, COMPLETE THE FORM TO UPDATE');
            this.Form.markAllAsTouched();
        }
    }
    confirmDialog() {
        const dialogConfig = new MatDialogConfig();
        dialogConfig.panelClass = 'newPasswordDialog';
        const dialogResponse = this.dialog.open(ConfirmDialogComponent, dialogConfig);
        dialogResponse.afterClosed().subscribe((result) => {
            if (result === 'true') {
                this.updateData();
            }
            else {
                return;
            }
        });
    }
    updateData() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o;
        this.interactionService.loadMessage('WE ARE UPDATING YOUR ACCOUNT, PLEASE WAIT...');
        this.spinner.show();
        const _uuid = v4();
        let daysallowed = this.Form.get('daysallowed').value;
        const phonenumber = this.Form.get('phonenumber').value;
        const branchcode = this.Form.get('branchcode').value;
        const branch = this.branches.find((item) => item.branchcode === branchcode);
        let postbody = {
            firstname: (_a = this.Form.get('firstname')) === null || _a === void 0 ? void 0 : _a.value,
            lastname: (_b = this.Form.get('lastname')) === null || _b === void 0 ? void 0 : _b.value,
            email: (_c = this.Form.get('email')) === null || _c === void 0 ? void 0 : _c.value,
            username: (_d = this.Form.get('username')) === null || _d === void 0 ? void 0 : _d.value,
            filtermode: (_e = this.Form.get('filtermode')) === null || _e === void 0 ? void 0 : _e.value,
            daysallowed: daysallowed.toString(),
            phonenumber: phonenumber.e164Number,
            branchcode: (_f = this.Form.get('branchcode')) === null || _f === void 0 ? void 0 : _f.value,
            branchname: branch.name,
            usergroupid: (_g = this.Form.get('usergroupid')) === null || _g === void 0 ? void 0 : _g.value,
            agencycode: (_h = this.Form.get('agencycode')) === null || _h === void 0 ? void 0 : _h.value,
            loginfrom: (_j = this.Form.get('loginfrom')) === null || _j === void 0 ? void 0 : _j.value,
            loginto: (_k = this.Form.get('loginto')) === null || _k === void 0 ? void 0 : _k.value,
            allowotp: (_l = this.Form.get('allowotp')) === null || _l === void 0 ? void 0 : _l.value,
            restrictipaddress: (_m = this.Form.get('restrictipaddress')) === null || _m === void 0 ? void 0 : _m.value,
            ipaddressvalue: (_o = this.Form.get('ipaddressvalue')) === null || _o === void 0 ? void 0 : _o.value,
        };
        const sub = this.userService
            .edit(this.userDetails.id, postbody, _uuid)
            .subscribe((data) => {
            this.spinner.hide();
            this.cdr.markForCheck();
            if (data['code'] === '200') {
                this.interactionService.sendMessage('reload_user');
                this.getpermissions();
                this.alertWithSuccess('USER ACCOUNT', 'ACCOUNT INFORMATION HAS BEEN UPDATED');
                this.router.navigate(['/dashboard/profile-overview']);
            }
            sub.unsubscribe();
        }, (error) => {
            console.log(error);
            this.spinner.hide();
            this.cdr.markForCheck();
            this.alertWithError('USER ACCOUNT', error === null || error === void 0 ? void 0 : error.message);
            sub.unsubscribe();
        });
    }
    cancel() {
        this.location.back();
    }
}
EditAccountProfileFormComponent.decorators = [
    { type: Component, args: [{
                selector: 'authdashboard-edit-profile-form',
                template: "<div class=\"container-fluid\">\n  <div class=\"row justify-content-center\">\n    <div class=\"col-lg-7 col-sm-10 col-12\">\n      <div class=\"card card-custom module-card mt-4\">\n        <div class=\"card-header\">\n          <div class=\"card-title\">\n            <h3 class=\"card-label main-title\" style=\"font-size: 15px\">\n              Edit Profile\n            </h3>\n          </div>\n          <div class=\"card-toolbar\">\n            <ul class=\"nav nav-bold nav-pills\">\n              <li class=\"nav-item\">\n                <a\n                  class=\"nav-link active\"\n                  style=\"border-radius: 30px\"\n                  data-toggle=\"tab\"\n                  href=\"#kt_tab_pane_7_1\"\n                  >Account</a\n                >\n              </li>\n              <li class=\"nav-item\">\n                <a\n                  class=\"nav-link\"\n                  style=\"border-radius: 30px\"\n                  data-toggle=\"tab\"\n                  href=\"#kt_tab_pane_7_2\"\n                  >Permission</a\n                >\n              </li>\n            </ul>\n          </div>\n        </div>\n        <div class=\"card-body body-content\">\n          <div class=\"tab-content\">\n            <div\n              class=\"tab-pane fade show active\"\n              id=\"kt_tab_pane_7_1\"\n              role=\"tabpanel\"\n              aria-labelledby=\"kt_tab_pane_7_1\"\n            >\n              <form novalidate [formGroup]=\"Form\">\n                <div class=\"row\">\n                  <div class=\"col-6\">\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label\n                          for=\"firstname\"\n                          class=\"font-weight-light main-title\"\n                          >First name</label\n                        >\n                        <input\n                          [class.is-invalid]=\"\n                            (Form.get('firstname').touched &&\n                              Form.get('firstname').invalid) ||\n                            Form.get('firstname').value === ''\n                          \"\n                          type=\"text\"\n                          class=\"form-control field-height\"\n                          formControlName=\"firstname\"\n                          placeholder=\"enter your firstname\"\n                          id=\"firstname\"\n                          trim\n                        />\n                        <div class=\"invalid-feedback\">\n                          <span\n                            *ngIf=\"Form.get('firstname').hasError('required')\"\n                            >Firstname is required</span\n                          >\n                        </div>\n                      </div>\n                    </div>\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label\n                          for=\"middlename\"\n                          class=\"font-weight-light main-title\"\n                          >Middle name</label\n                        >\n                        <input\n                          type=\"text\"\n                          class=\"form-control field-height\"\n                          formControlName=\"middlename\"\n                          placeholder=\"enter your middlename\"\n                          id=\"middlename\"\n                          trim\n                        />\n                      </div>\n                    </div>\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label\n                          for=\"lastname\"\n                          class=\"font-weight-light main-title\"\n                          >Last name</label\n                        >\n                        <input\n                          [class.is-invalid]=\"\n                            (Form.get('lastname').touched &&\n                              Form.get('lastname').invalid) ||\n                            Form.get('lastname').value === ''\n                          \"\n                          type=\"text\"\n                          class=\"form-control field-height\"\n                          formControlName=\"lastname\"\n                          placeholder=\"enter your lastname\"\n                          id=\"lastname\"\n                          trim\n                        />\n                        <div class=\"invalid-feedback\">\n                          <span\n                            *ngIf=\"Form.get('lastname').hasError('required')\"\n                            >Lastname is required</span\n                          >\n                        </div>\n                      </div>\n                    </div>\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label\n                          for=\"username\"\n                          class=\"font-weight-light main-title\"\n                          >Username</label\n                        >\n                        <input\n                          [class.is-invalid]=\"\n                            (Form.get('username').touched &&\n                              Form.get('username').invalid) ||\n                            (Form.get('username').touched &&\n                              Form.get('username').hasError('isUsed')) ||\n                            Form.get('username').value === ''\n                          \"\n                          type=\"text\"\n                          class=\"form-control field-height\"\n                          formControlName=\"username\"\n                          placeholder=\"enter your username\"\n                          id=\"username\"\n                          trim\n                        />\n                        <div class=\"invalid-feedback\">\n                          <span\n                            *ngIf=\"Form.get('username').hasError('required')\"\n                            >Username is required</span\n                          >\n                          <span *ngIf=\"Form.get('username').hasError('isUsed')\"\n                            >Username already <strong>Exist</strong></span\n                          >\n                        </div>\n                      </div>\n                    </div>\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label for=\"email\" class=\"font-weight-light main-title\"\n                          >Email</label\n                        >\n                        <input\n                          [class.is-invalid]=\"\n                            (Form.get('email').touched &&\n                              Form.get('email').invalid) ||\n                            (Form.get('email').touched &&\n                              Form.get('email').hasError('isUsed')) ||\n                            Form.get('email').value === ''\n                          \"\n                          type=\"email\"\n                          class=\"form-control field-height\"\n                          formControlName=\"email\"\n                          placeholder=\"enter your email address\"\n                          id=\"email\"\n                          trim\n                        />\n                        <div class=\"invalid-feedback\">\n                          <span *ngIf=\"Form.get('email').hasError('required')\"\n                            >Email is required</span\n                          >\n                          <span *ngIf=\"Form.get('email').hasError('email')\"\n                            >Email must be <strong>Valid</strong></span\n                          >\n                          <span *ngIf=\"Form.get('email').hasError('isUsed')\"\n                            >Email already <strong>Exist</strong></span\n                          >\n                        </div>\n                      </div>\n                    </div>\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label\n                          class=\"control-label font-weight-light main-title d-block\"\n                          ><strong>Phone Number</strong></label\n                        >\n                        <ngx-intl-tel-input\n                          [inputId]=\"'input'\"\n                          [cssClass]=\"'form-control phone-style-col-4'\"\n                          [preferredCountries]=\"[\n                            CountryISO.Ghana,\n                            CountryISO.Kenya\n                          ]\"\n                          [enableAutoCountrySelect]=\"false\"\n                          [enablePlaceholder]=\"true\"\n                          [searchCountryFlag]=\"true\"\n                          [searchCountryField]=\"[\n                            SearchCountryField.Iso2,\n                            SearchCountryField.Name\n                          ]\"\n                          [selectFirstCountry]=\"false\"\n                          [selectedCountryISO]=\"institutionCountry\"\n                          [tooltipField]=\"TooltipLabel.Name\"\n                          [phoneValidation]=\"true\"\n                          [separateDialCode]=\"separateDialCode\"\n                          name=\"phone\"\n                          formControlName=\"phonenumber\"\n                        >\n                        </ngx-intl-tel-input>\n                        <span\n                          *ngIf=\"\n                            Form.get('phonenumber').touched &&\n                            Form.get('phonenumber').invalid\n                          \"\n                          class=\"d-block text-danger help-block\"\n                        >\n                          Phone number is not valid\n                        </span>\n                        <span\n                          class=\"d-block text-danger\"\n                          *ngIf=\"\n                            Form.get('phonenumber').hasError('isUsed') &&\n                            Form.get('phonenumber').valid\n                          \"\n                          >Phone number already <strong>Exist</strong></span\n                        >\n                      </div>\n                    </div>\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label\n                          for=\"filtermode\"\n                          class=\"font-weight-light main-title\"\n                          >Filter Mode</label\n                        >\n                        <select\n                          [class.is-invalid]=\"\n                            (Form.get('filtermode').touched &&\n                              Form.get('filtermode').invalid) ||\n                            Form.get('filtermode').value === ''\n                          \"\n                          class=\"custom-select field-height\"\n                          formControlName=\"filtermode\"\n                        >\n                          <option value=\"USER\" selected=\"selected\">USER</option>\n                          <option value=\"BRANCH\">BRANCH</option>\n                          <option\n                            *ngIf=\"\n                              filtermode == 'ALL' ||\n                              filtermode == 'APEXREGION' ||\n                              filtermode == 'APEXNATIONAL'\n                            \"\n                            value=\"ALL\"\n                          >\n                            ALL\n                          </option>\n                          <option\n                            *ngIf=\"\n                              filtermode == 'APEXREGION' ||\n                              filtermode == 'APEXNATIONAL'\n                            \"\n                            value=\"APEXREGION\"\n                          >\n                            APEXREGION\n                          </option>\n                          <option\n                            *ngIf=\"filtermode == 'APEXNATIONAL'\"\n                            value=\"APEXNATIONAL\"\n                          >\n                            APEXNATIONAL\n                          </option>\n                        </select>\n                        <div class=\"invalid-feedback\">\n                          <span\n                            *ngIf=\"\n                              Form.get('filtermode').hasError('required') ||\n                              Form.get('filtermode').value === ''\n                            \"\n                            >Filter Mode is <strong>Required</strong></span\n                          >\n                        </div>\n                      </div>\n                    </div>\n\n                    <div class=\"col-md-12\">\n                      <div>\n                        <label\n                          for=\"exampleSelect2\"\n                          class=\"d-block mb-1 font-weight-light main-title\"\n                          >Days Allowed</label\n                        >\n                        <mat-form-field\n                          appearance=\"outline\"\n                          class=\"example-full-width\"\n                        >\n                          <mat-select formControlName=\"daysallowed\" multiple>\n                            <mat-option *ngFor=\"let day of days\" [value]=\"day\"\n                              >{{ day }}\n                            </mat-option>\n                          </mat-select>\n                          <mat-error\n                            *ngIf=\"Form.get('daysallowed').hasError('required')\"\n                          >\n                            Field is required\n                          </mat-error>\n                        </mat-form-field>\n                      </div>\n                    </div>\n                  </div>\n                  <div class=\"col-6\">\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label\n                          for=\"usergroupid\"\n                          class=\"font-weight-light main-title\"\n                          >User Group</label\n                        >\n                        <select\n                          [class.is-invalid]=\"\n                            (Form.get('usergroupid').touched &&\n                              Form.get('usergroupid').invalid) ||\n                            Form.get('usergroupid').value === ''\n                          \"\n                          class=\"custom-select field-height\"\n                          formControlName=\"usergroupid\"\n                          trim\n                        >\n                          <option selected disabled>select a group</option>\n                          <ng-container *ngIf=\"usergroups\">\n                            <option\n                              *ngFor=\"let group of usergroups\"\n                              value=\"{{ group.groupid }}\"\n                            >\n                              {{ group.name }}\n                            </option>\n                          </ng-container>\n                        </select>\n                        <div class=\"invalid-feedback\">\n                          <span\n                            *ngIf=\"\n                              Form.get('usergroupid').hasError('required') ||\n                              Form.get('usergroupid').value === ''\n                            \"\n                            >User Group is <strong>Required</strong></span\n                          >\n                        </div>\n                      </div>\n                    </div>\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label for=\"branch\" class=\"font-weight-light main-title\"\n                          >Branch Name</label\n                        >\n                        <select\n                          (change)=\"branchChange($event)\"\n                          [class.is-invalid]=\"\n                            (Form.get('branchcode').touched &&\n                              Form.get('branchcode').invalid) ||\n                            Form.get('branchcode').value === ''\n                          \"\n                          class=\"custom-select field-height\"\n                          formControlName=\"branchcode\"\n                          trim\n                        >\n                          <option selected disabled>\n                            Open this select menu\n                          </option>\n                          <ng-container *ngIf=\"branches\">\n                            <option\n                              *ngFor=\"let branch of branches\"\n                              value=\"{{ branch.branchcode }}\"\n                            >\n                              {{ branch.name }}\n                            </option>\n                          </ng-container>\n                        </select>\n                        <div class=\"invalid-feedback\">\n                          <span\n                            *ngIf=\"\n                              Form.get('branchcode').hasError('required') ||\n                              Form.get('branchcode').value === ''\n                            \"\n                            >Branch is <strong>Required</strong></span\n                          >\n                        </div>\n                      </div>\n                    </div>\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label for=\"agency\" class=\"font-weight-light main-title\"\n                          >Agency</label\n                        >\n                        <select\n                          [class.is-invalid]=\"\n                            (Form.get('agencycode').touched &&\n                              Form.get('agencycode').invalid) ||\n                            Form.get('agencycode').value === ''\n                          \"\n                          class=\"custom-select mb-3 field-height\"\n                          formControlName=\"agencycode\"\n                          trim\n                        >\n                          <option selected disabled>\n                            Open this select menu\n                          </option>\n                          <ng-container *ngIf=\"agencies\">\n                            <option\n                              *ngFor=\"let agency of agencies\"\n                              value=\"{{ agency.code }}\"\n                            >\n                              {{ agency.name }}\n                            </option>\n                          </ng-container>\n                        </select>\n                        <div class=\"invalid-feedback\">\n                          <span\n                            *ngIf=\"\n                              Form.get('agencycode').hasError('required') ||\n                              Form.get('agencycode').value === ''\n                            \"\n                            >Agency is <strong>Required</strong></span\n                          >\n                        </div>\n                      </div>\n                    </div>\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label\n                          for=\"loginfrom\"\n                          class=\"font-weight-light main-title\"\n                          >Login From</label\n                        >\n                        <input\n                          [class.is-invalid]=\"\n                            (Form.get('loginfrom').touched &&\n                              Form.get('loginfrom').invalid) ||\n                            Form.get('loginfrom').value === ''\n                          \"\n                          type=\"time\"\n                          class=\"form-control field-height\"\n                          formControlName=\"loginfrom\"\n                          id=\"loginfrom\"\n                          trim\n                        />\n                        <div class=\"invalid-feedback\">\n                          <span\n                            *ngIf=\"\n                              Form.get('loginfrom').hasError('required') ||\n                              Form.get('loginfrom').value === ''\n                            \"\n                            >Login From is <strong>Required</strong></span\n                          >\n                        </div>\n                      </div>\n                    </div>\n                    <div class=\"col-md-12\">\n                      <div class=\"form-group\">\n                        <label\n                          for=\"loginto\"\n                          class=\"font-weight-light main-title\"\n                          >Login To</label\n                        >\n                        <input\n                          [class.is-invalid]=\"\n                            (Form.get('loginto').touched &&\n                              Form.get('loginto').invalid) ||\n                            Form.get('loginto').value === ''\n                          \"\n                          type=\"time\"\n                          class=\"form-control field-height\"\n                          formControlName=\"loginto\"\n                          id=\"loginto\"\n                        />\n                        <div class=\"invalid-feedback\">\n                          <span\n                            *ngIf=\"\n                              Form.get('loginto').hasError('required') ||\n                              Form.get('loginto').value === ''\n                            \"\n                            >Login To is <strong>Required</strong></span\n                          >\n                        </div>\n                      </div>\n                    </div>\n\n                    <div class=\"col-md-12 mb-4\">\n                      <label\n                        class=\"checkbox checkbox-square font-weight-light main-title\"\n                      >\n                        <input\n                          type=\"checkbox\"\n                          name=\"Checkboxes13_1\"\n                          formControlName=\"restrictipaddress\"\n                        />\n                        <span class=\"mr-3\"></span>\n                        Restrict IP Address\n                      </label>\n                    </div>\n\n                    <div class=\"col-md-12 mb-4\">\n                      <label\n                        class=\"checkbox checkbox-square font-weight-light main-title\"\n                      >\n                        <input\n                          type=\"checkbox\"\n                          name=\"Checkboxes13\"\n                          formControlName=\"allowotp\"\n                        />\n                        <span class=\"mr-3\"></span>\n                        Allow OTP\n                      </label>\n                    </div>\n\n                    <div\n                      class=\"col-md-12\"\n                      *ngIf=\"Form.get('restrictipaddress').value === true\"\n                    >\n                      <div class=\"form-group\">\n                        <label\n                          for=\"restrictipaddress\"\n                          class=\"font-weight-light main-title\"\n                          >Ip Address Range</label\n                        >\n                        <input\n                          [class.is-invalid]=\"\n                            (Form.get('ipaddressvalue').touched &&\n                              Form.get('ipaddressvalue').invalid) ||\n                            Form.get('ipaddressvalue').value === ''\n                          \"\n                          type=\"text\"\n                          class=\"form-control field-height\"\n                          formControlName=\"ipaddressvalue\"\n                          id=\"ipaddressvalue\"\n                          trim\n                        />\n                        <div class=\"invalid-feedback\">\n                          <span\n                            *ngIf=\"\n                              Form.get('ipaddressvalue').hasError('required') ||\n                              Form.get('ipaddressvalue').value === ''\n                            \"\n                            >IP Address Range is <strong>Required</strong></span\n                          >\n                        </div>\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </form>\n            </div>\n            <div\n              class=\"tab-pane fade\"\n              id=\"kt_tab_pane_7_2\"\n              role=\"tabpanel\"\n              aria-labelledby=\"kt_tab_pane_7_2\"\n            >\n              <div class=\"d-flex justify-content-end\">\n                <div class=\"form-group\">\n                  <label\n                    class=\"text-uppercase font-weight-light d-block text-right font-weight-bolder\"\n                    >FILTER PERMISSION</label\n                  >\n                  <input\n                    [(ngModel)]=\"search\"\n                    type=\"text\"\n                    class=\"form-control filter-search\"\n                    placeholder=\"Enter module name...\"\n                  />\n                </div>\n              </div>\n\n              <div\n                *ngIf=\"userpermissions\"\n                class=\"accordion accordion-light accordion-toggle-arrow\"\n                id=\"accordionExample5\"\n              >\n                <div\n                  class=\"card\"\n                  *ngFor=\"\n                    let permit of userpermissions | permissionfilter: search\n                  \"\n                >\n                  <div class=\"card-header\" [attr.id]=\"'headerOne' + permit.id\">\n                    <div\n                      class=\"card-title\"\n                      data-toggle=\"collapse\"\n                      [attr.data-target]=\"'#' + 'module' + permit.id\"\n                    >\n                      <span\n                        class=\"switch switch-sm switch-icon switch-primary font-weight-light main-title\"\n                      >\n                        <label>\n                          <input\n                            type=\"checkbox\"\n                            name=\"select\"\n                            (change)=\"setModuleEvent($event, permit.moduleid)\"\n                            [(ngModel)]=\"permit.active\"\n                            [value]=\"permit.id\"\n                          />\n                          <span class=\"mr-3\"></span>\n                          {{ permit.modulename }}\n                        </label>\n                      </span>\n                    </div>\n                  </div>\n                  <div\n                    [attr.id]=\"'module' + permit.id\"\n                    class=\"collapse show\"\n                    data-parent=\"#accordionExample5\"\n                  >\n                    <div class=\"card-body\">\n                      <!---->\n                      <div\n                        *ngIf=\"permit.sub.length\"\n                        class=\"accordion accordion-light accordion-toggle-arrow\"\n                        id=\"accordionExample4\"\n                      >\n                        <div\n                          class=\"card ml-4\"\n                          *ngFor=\"let item of permit.sub; let i = index\"\n                        >\n                          <div\n                            class=\"card-header\"\n                            [attr.id]=\"'headerTwo' + item.id\"\n                          >\n                            <div\n                              class=\"card-title\"\n                              data-toggle=\"collapse\"\n                              [attr.data-target]=\"'#' + 'event' + item.id\"\n                            >\n                              <span\n                                class=\"switch switch-sm switch-icon switch-warning font-weight-light main-title\"\n                              >\n                                <label>\n                                  <input\n                                    type=\"checkbox\"\n                                    name=\"select\"\n                                    (change)=\"\n                                      setModuleEvent($event, item.moduleid)\n                                    \"\n                                    [(ngModel)]=\"item.active\"\n                                    [value]=\"item.moduleid\"\n                                  />\n                                  <span class=\"mr-3\"></span>\n                                  {{ item.modulename }}\n                                </label>\n                              </span>\n                            </div>\n                          </div>\n                          <div\n                            [attr.id]=\"'event' + item.id\"\n                            class=\"collapse show\"\n                            data-parent=\"#accordionExample4\"\n                          >\n                            <div class=\"card-body ml-4\">\n                              <!---->\n                              <!--Event Permission-->\n                              <div\n                                style=\"width: 100%; flex-wrap: wrap\"\n                                *ngIf=\"item.events.length\"\n                                class=\"d-flex align-items-center role-border-bottom-grey role-py-15 role-bg-grey\"\n                              >\n                                <div\n                                  style=\"margin: 10px 20px\"\n                                  class=\"role-timeline-3-item role-timeline-3-item-child\"\n                                  *ngFor=\"let event of item.events\"\n                                >\n                                  <span class=\"role-timeline-3-item-time\">\n                                    <span\n                                      class=\"switch switch-sm switch-icon switch-success\"\n                                    >\n                                      <label class=\"main-title\">\n                                        <input\n                                          type=\"checkbox\"\n                                          name=\"select\"\n                                          (change)=\"\n                                            setEvent($event, event.appeventid)\n                                          \"\n                                          [(ngModel)]=\"event.active\"\n                                          value=\"event.appeventid\"\n                                        />\n                                        <span class=\"mr-3\"></span>\n                                        {{ event.eventname }}\n                                      </label>\n                                    </span>\n                                  </span>\n                                </div>\n                              </div>\n                              <!--Event Permission-->\n                            </div>\n                          </div>\n                        </div>\n                      </div>\n                    </div>\n                  </div>\n                </div>\n              </div>\n            </div>\n          </div>\n        </div>\n      </div>\n\n      <div class=\"text-center mt-4\">\n        <button\n          (click)=\"cancel()\"\n          type=\"button\"\n          class=\"btn btn-outline-secondary btn-shadow mr-3 action-btn\"\n        >\n          Cancel\n        </button>\n        <button\n          type=\"button\"\n          class=\"btn btn-primary action-btn btn-shadow\"\n          (click)=\"update()\"\n        >\n          <span>Submit</span>\n        </button>\n      </div>\n    </div>\n  </div>\n</div>\n",
                styles: [".notify-icon{box-shadow:0 1px 10px 0 rgba(0,0,0,.2)!important}.field-height,.module-card{background-color:var(--background-color)}.field-height{height:48px;border-radius:10px;border:1px solid var(--border-color);color:var(--subtext-color)}.module-card .body-content{height:500px;overflow:auto}.filter-search{border-right:0;border-left:0;border-top:0;border-radius:0;width:330px;height:40px;border:1px solid var(--border-color);background-color:var(--background-color);color:var(--subtext-color)}.action-btn{padding:12px 27px;border-radius:12px}#accordionExample5 .card,#accordionExample5 .card-body,#accordionExample5 .card-header{background-color:var(--background-color)}"]
            },] }
];
EditAccountProfileFormComponent.ctorParameters = () => [
    { type: FormBuilder },
    { type: UsergroupService },
    { type: InstitutionService },
    { type: AuthenticationService },
    { type: UsersService },
    { type: MatDialog },
    { type: ChangeDetectorRef },
    { type: Router },
    { type: NgxSpinnerService },
    { type: InteractionService },
    { type: Location }
];

class SearchResultComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
        this.accountdetails = [];
        this.accountdetails = data.details;
        console.log(this.accountdetails);
    }
    ngOnInit() {
    }
    confirm() {
        this.dialogRef.close({ confirm: this.accountdetails });
    }
    close() {
        this.dialogRef.close();
    }
    select(customer) {
        this.dialogRef.close({ confirm: customer });
    }
}
SearchResultComponent.decorators = [
    { type: Component, args: [{
                selector: 'kt-search-result',
                template: "<div class=\"card card-custom module-card gutter-b m-0\">\n  <div class=\"card-body\">\n    <div class=\"row mb-3\">\n      <div class=\"col-12 text-center\">\n        <span class=\"svg-icon svg-icon-primary svg-icon-2x\"\n          ><!--begin::Svg Icon | path:C:\\wamp64\\www\\keenthemes\\themes\\metronic\\theme\\html\\demo1\\dist/../src/media/svg/icons\\Design\\ZoomMinus.svg--><svg\n            xmlns=\"http://www.w3.org/2000/svg\"\n            xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n            width=\"24px\"\n            height=\"24px\"\n            viewBox=\"0 0 24 24\"\n            version=\"1.1\"\n          >\n            <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n              <rect x=\"0\" y=\"0\" width=\"24\" height=\"24\" />\n              <path\n                d=\"M14.2928932,16.7071068 C13.9023689,16.3165825 13.9023689,15.6834175 14.2928932,15.2928932 C14.6834175,14.9023689 15.3165825,14.9023689 15.7071068,15.2928932 L19.7071068,19.2928932 C20.0976311,19.6834175 20.0976311,20.3165825 19.7071068,20.7071068 C19.3165825,21.0976311 18.6834175,21.0976311 18.2928932,20.7071068 L14.2928932,16.7071068 Z\"\n                fill=\"#000000\"\n                fill-rule=\"nonzero\"\n                opacity=\"0.3\"\n              />\n              <path\n                d=\"M11,16 C13.7614237,16 16,13.7614237 16,11 C16,8.23857625 13.7614237,6 11,6 C8.23857625,6 6,8.23857625 6,11 C6,13.7614237 8.23857625,16 11,16 Z M11,18 C7.13400675,18 4,14.8659932 4,11 C4,7.13400675 7.13400675,4 11,4 C14.8659932,4 18,7.13400675 18,11 C18,14.8659932 14.8659932,18 11,18 Z\"\n                fill=\"#000000\"\n                fill-rule=\"nonzero\"\n              />\n              <rect\n                fill=\"#000000\"\n                opacity=\"0.3\"\n                x=\"9\"\n                y=\"10.5\"\n                width=\"4\"\n                height=\"1\"\n                rx=\"0.5\"\n              />\n            </g></svg\n          ><!--end::Svg Icon--></span\n        >\n        <h6 class=\"font-weight-bold main-title\">RESULT SUMMARY</h6>\n      </div>\n    </div>\n\n    <mat-dialog-content>\n      <div class=\"mt-4\" *ngIf=\"accountdetails.length\">\n        <!--begin::Item-->\n        <div\n          class=\"d-flex align-items-center mb-10\"\n          *ngFor=\"let customer of accountdetails; let i = index\"\n        >\n          <!--begin::Symbol-->\n          <div class=\"symbol symbol-40 symbol-light-success mr-5\">\n            <span class=\"symbol-label\">\n              <img\n                src=\"assets/images/avatars/001-boy.svg\"\n                class=\"h-75 align-self-end\"\n                alt=\"\"\n              />\n            </span>\n          </div>\n          <!--end::Symbol-->\n\n          <!--begin::Text-->\n          <div class=\"d-flex flex-column flex-grow-1 font-weight-bold\">\n            <a\n              (click)=\"select(customer)\"\n              class=\"main-title text-hover-primary mb-1 font-size-lg\"\n              >{{ customer.customername }}</a\n            >\n            <span class=\"text-muted\" *ngIf=\"customer.accountnumber\">{{ customer.accountnumber }}</span>\n            <span class=\"text-muted mt-1\" style=\"font-size: 12px;\" *ngIf=\"customer.customerid\">{{ customer.customerid }}</span>\n            <span class=\"text-muted mt-1\" style=\"font-size: 12px;\" *ngIf=\"customer.status\">{{ customer.status }}</span>\n          </div>\n          <!--end::Text-->\n\n          <!--begin::Dropdown-->\n          <a\n            (click)=\"select(customer)\"\n            class=\"btn btn-hover-light-primary btn-sm btn-icon\"\n            data-toggle=\"dropdown\"\n            aria-haspopup=\"true\"\n            aria-expanded=\"false\"\n          >\n            <span class=\"svg-icon svg-icon-primary svg-icon-2x\"\n              ><!--begin::Svg Icon | path:C:\\wamp64\\www\\keenthemes\\themes\\metronic\\theme\\html\\demo1\\dist/../src/media/svg/icons\\Navigation\\Double-check.svg--><svg\n                xmlns=\"http://www.w3.org/2000/svg\"\n                xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n                width=\"24px\"\n                height=\"24px\"\n                viewBox=\"0 0 24 24\"\n                version=\"1.1\"\n              >\n                <g\n                  stroke=\"none\"\n                  stroke-width=\"1\"\n                  fill=\"none\"\n                  fill-rule=\"evenodd\"\n                >\n                  <polygon points=\"0 0 24 0 24 24 0 24\" />\n                  <path\n                    d=\"M9.26193932,16.6476484 C8.90425297,17.0684559 8.27315905,17.1196257 7.85235158,16.7619393 C7.43154411,16.404253 7.38037434,15.773159 7.73806068,15.3523516 L16.2380607,5.35235158 C16.6013618,4.92493855 17.2451015,4.87991302 17.6643638,5.25259068 L22.1643638,9.25259068 C22.5771466,9.6195087 22.6143273,10.2515811 22.2474093,10.6643638 C21.8804913,11.0771466 21.2484189,11.1143273 20.8356362,10.7474093 L17.0997854,7.42665306 L9.26193932,16.6476484 Z\"\n                    fill=\"#000000\"\n                    fill-rule=\"nonzero\"\n                    opacity=\"0.3\"\n                    transform=\"translate(14.999995, 11.000002) rotate(-180.000000) translate(-14.999995, -11.000002) \"\n                  />\n                  <path\n                    d=\"M4.26193932,17.6476484 C3.90425297,18.0684559 3.27315905,18.1196257 2.85235158,17.7619393 C2.43154411,17.404253 2.38037434,16.773159 2.73806068,16.3523516 L11.2380607,6.35235158 C11.6013618,5.92493855 12.2451015,5.87991302 12.6643638,6.25259068 L17.1643638,10.2525907 C17.5771466,10.6195087 17.6143273,11.2515811 17.2474093,11.6643638 C16.8804913,12.0771466 16.2484189,12.1143273 15.8356362,11.7474093 L12.0997854,8.42665306 L4.26193932,17.6476484 Z\"\n                    fill=\"#000000\"\n                    fill-rule=\"nonzero\"\n                    transform=\"translate(9.999995, 12.000002) rotate(-180.000000) translate(-9.999995, -12.000002) \"\n                  />\n                </g></svg\n              ><!--end::Svg Icon--></span\n            >\n          </a>\n          <!--end::Dropdown-->\n        </div>\n        <!--end::Item-->\n      </div>\n      <!-- <div class=\"row\">\n    <div class=\"col\">\n      <section class=\"mb-2\">\n        <span class=\"text-muted\" style=\"font-size: 11px\">Account Name</span>\n        <span\n          class=\"d-block font-weight-bold text-uppercase\"\n          style=\"font-size: 14px\"\n          >{{ accountdetails.customername }}</span\n        >\n      </section>\n\n      <section class=\"mb-2\">\n        <span class=\"text-muted\" style=\"font-size: 11px\">Account Number</span>\n        <span\n          class=\"d-block font-weight-bolder text-uppercase\"\n          style=\"font-size: 16px\"\n        >\n          {{ accountdetails.accountnumber }}</span\n        >\n      </section>\n    </div>\n  </div> --> </mat-dialog-content>\n\n    <div class=\"text-center\">\n      <a\n        (click)=\"close()\"\n        class=\"btn btn-text-dark-50 btn-icon-danger font-weight-light btn-hover-bg-light mr-3 mt-3 action-btn\"\n      >\n        <i class=\"flaticon2-cancel-music\" style=\"font-size: 12px\"></i> CANCEL\n      </a>\n      <!-- <a\n        style=\"padding: 10px 20px\"\n        (click)=\"confirm()\"\n        class=\"btn btn-text-dark-50 btn-icon-primary font-weight-light btn-hover-bg-light mt-3\"\n      >\n        <i class=\"fas fa-check\" style=\"font-size: 12px\"></i> CONFIRM\n      </a> -->\n    </div>\n  </div>\n</div>\n",
                styles: [".module-card{background-color:var(--background-color)}.action-btn,.close-btn{padding:12px 25px;border-radius:35px}"]
            },] }
];
SearchResultComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];

class PdfViewerComponent {
    constructor(dialogRef, data, cdr) {
        this.dialogRef = dialogRef;
        this.data = data;
        this.cdr = cdr;
        console.log(data);
        this.title = data.name;
        if (data === null || data === void 0 ? void 0 : data.image.includes('image')) {
            this.image = data.image;
            this.cdr.markForCheck();
        }
        else if (data === null || data === void 0 ? void 0 : data.image.includes('application')) {
            this.pdfSource = data.image;
            this.cdr.markForCheck();
        }
    }
    ngOnInit() { }
}
PdfViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'kt-pdf-viewer',
                template: "<div class=\"card card-custom\">\n  <div class=\"card-header card-header-tabs-line\">\n    <div class=\"card-title\">\n      <h3 class=\"card-label\" style=\"font-size: 14px\">\n        {{ title }}\n      </h3>\n    </div>\n    <div class=\"card-toolbar\">\n      <button\n        [mat-dialog-close]=\"false\"\n        class=\"btn btn-icon btn-outline-danger\"\n      >\n        <i class=\"fas fa-times\"></i>\n      </button>\n    </div>\n  </div>\n  <div class=\"card-body\" style=\"padding: 23px 38px\">\n    <mat-dialog-content>\n      <div class=\"container\">\n        <ng-container *ngIf=\"image; else elseTemplate\">\n          <img\n            [src]=\"image\"\n            style=\"width: 100%\"\n            class=\"img-fluid rounded mx-auto d-block\"\n            alt=\"title\"\n          />\n        </ng-container>\n        <ng-template #elseTemplate>\n          <pdf-viewer\n            [src]=\"pdfSource\"\n            [original-size]=\"false\"\n            [render-text]=\"true\"\n            [show-borders]=\"true\"\n            style=\"display: block\"\n          ></pdf-viewer>\n        </ng-template>\n      </div>\n    </mat-dialog-content>\n  </div>\n  <div class=\"card-footer d-flex justify-content-end\">\n    <a\n      class=\"btn btn-danger font-weight-bold mr-3 py-3 px-4\"\n      [mat-dialog-close]=\"false\"\n      >Cancel</a\n    >\n  </div>\n</div>\n",
                styles: [""]
            },] }
];
PdfViewerComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] },
    { type: ChangeDetectorRef }
];

class PinConfirmationComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    close() {
        this.dialogRef.close();
    }
    ngOnInit() { }
}
PinConfirmationComponent.decorators = [
    { type: Component, args: [{
                selector: "kt-pin-confirmation",
                template: "<h1 mat-dialog-title style=\"padding: 10px 20px; font-size: 17px\">\n  <i class=\"fas fa-key mr-2 text-warning\"></i>\n  Pin Confirmation\n</h1>\n<div mat-dialog-content style=\"padding: 12px 40px\">\n  <form action=\"\">\n    <div class=\"form-group\">\n      <label>Enter Pin</label>\n      <input\n        type=\"text\"\n        name=\"pin\"\n        class=\"form-control form-control-solid\"\n        placeholder=\"enter pin here...\"\n        [(ngModel)]=\"data.pin\"\n      />\n    </div>\n  </form>\n</div>\n<div mat-dialog-actions align=\"end\">\n  <button mat-button [mat-dialog-close]=\"close\">Close</button>\n  <button mat-button [mat-dialog-close]=\"data.pin\">Submit</button>\n</div>\n",
                styles: [""]
            },] }
];
PinConfirmationComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];

class MapLocationDialogComponent {
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
        this.zoom = 15;
        console.log(data);
        this.title = data.name;
        this.latitude = data.latitude;
        this.longitude = data.longitude;
    }
    ngOnInit() { }
}
MapLocationDialogComponent.decorators = [
    { type: Component, args: [{
                selector: "kt-map-location-dialog",
                template: "<div class=\"card card-custom module-card\" style=\"box-shadow: none !important\">\n  <div class=\"card-header card-header-tabs-line\">\n    <div class=\"card-title\">\n      <h3 class=\"card-label main-title\" style=\"font-size: 14px\">\n        {{ title }}\n      </h3>\n    </div>\n    <div class=\"card-toolbar\">\n      <button\n        [mat-dialog-close]=\"false\"\n        class=\"btn btn-icon btn-outline-danger\"\n      >\n        <i class=\"fas fa-times\"></i>\n      </button>\n    </div>\n  </div>\n  <div class=\"card-body\" style=\"padding: 23px 38px\">\n    <mat-dialog-content>\n      <ng-container\n        *ngIf=\"\n          (latitude == 0 && longitude == 0) ||\n            (latitude == null && longitude == null);\n          else elseTemplate\n        \"\n      >\n        <div class=\"alert alert-custom alert-warning\" role=\"alert\">\n          <div class=\"alert-icon\">\n            <i class=\"flaticon-questions-circular-button\"></i>\n          </div>\n          <div class=\"alert-text\">\n            No GPS Coordinate to locate this collateral!\n          </div>\n        </div>\n      </ng-container>\n      <ng-template #elseTemplate>\n        <agm-map [latitude]=\"latitude\" [longitude]=\"longitude\" [zoom]=\"zoom\">\n          <agm-marker\n            [latitude]=\"latitude\"\n            [longitude]=\"longitude\"\n          ></agm-marker>\n        </agm-map>\n      </ng-template>\n    </mat-dialog-content>\n  </div>\n  <div class=\"card-footer d-flex justify-content-end\">\n    <a\n      class=\"btn btn-danger btn-shadow font-weight-bold mr-3 action-btn\"\n      [mat-dialog-close]=\"false\"\n      >Cancel</a\n    >\n  </div>\n</div>\n",
                styles: ["agm-map{height:300px}.module-card{background-color:var(--background-color)}.main-title{color:var(--text-color)}.action-btn,.close-btn{padding:12px 25px;border-radius:35px}"]
            },] }
];
MapLocationDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];

const ɵ0$2 = (toast) => {
    toast.addEventListener('mouseenter', Swal.stopTimer);
    toast.addEventListener('mouseleave', Swal.resumeTimer);
};
const Toast$2 = Swal.mixin({
    toast: true,
    position: 'top-end',
    showConfirmButton: false,
    timer: 3000,
    timerProgressBar: true,
    didOpen: ɵ0$2,
});
class ValidateTellerPinComponent {
    constructor(dialogRef, data, formBuilder) {
        this.dialogRef = dialogRef;
        this.data = data;
        this.formBuilder = formBuilder;
        this.Form = this.formBuilder.group({
            pin: [
                '',
                [
                    Validators.required,
                    Validators.maxLength(4),
                    Validators.pattern('^[0-9]*$'),
                ],
            ],
        });
    }
    ngOnInit() { }
    close() {
        this.dialogRef.close('false');
    }
    submit() {
        console.log(this.Form);
        if (this.Form.valid) {
            this.dialogRef.close({ data: this.Form.get('pin').value });
        }
        else {
            Toast$2.fire({
                icon: 'error',
                title: 'Please Enter your Pin to validate your request',
            });
        }
    }
}
ValidateTellerPinComponent.decorators = [
    { type: Component, args: [{
                selector: 'kt-validate-teller-pin',
                template: "<div class=\"card card-custom module-card\">\n  <div class=\"card-header card-header-tabs-line\">\n    <div class=\"card-title\">\n      <h3 class=\"card-label main-title\" style=\"font-size: 14px\">\n        Teller Validation\n      </h3>\n    </div>\n    <div class=\"card-toolbar\">\n      <button\n        [mat-dialog-close]=\"false\"\n        class=\"btn btn-icon btn-outline-danger\"\n      >\n        <i class=\"fas fa-times\" style=\"font-size: 10px\"></i>\n      </button>\n    </div>\n  </div>\n  <div class=\"card-body\" style=\"padding: 23px 38px\">\n    <mat-dialog-content>\n      <form novalidate [formGroup]=\"Form\">\n        <div class=\"form-group\">\n          <label class=\"font-weight-bold\">Enter Pin </label>\n          <input\n            [class.is-invalid]=\"\n              Form.get('pin').touched && Form.get('pin').invalid\n            \"\n            formControlName=\"pin\"\n            type=\"password\"\n            class=\"form-control field-height\"\n            placeholder=\"Enter your pin\"\n          />\n          <span class=\"form-text text-muted\"\n            >enter your pin to validate your request.</span\n          >\n          <div class=\"invalid-feedback\">\n            <span *ngIf=\"Form.get('pin').errors?.required\"\n              >Your pin is required</span\n            >\n            <span *ngIf=\"Form.get('pin').errors?.pattern\"\n              >Pin must contain numbers [0-9] only!!!</span\n            >\n\n            <span *ngIf=\"Form.get('pin').errors?.maxlength\"\n              >Pin must be\n              {{ Form.get(\"pin\").errors?.maxlength?.requiredLength }}\n              characters</span\n            >\n          </div>\n        </div>\n      </form>\n    </mat-dialog-content>\n  </div>\n  <div class=\"card-footer d-flex justify-content-end\">\n    <a\n      class=\"btn btn-danger font-weight-bold mr-3 action-btn btn-shadow\"\n      (click)=\"close()\"\n      >Cancel</a\n    >\n    <button\n      (click)=\"submit()\"\n      class=\"btn btn-success font-weight-light action-btn btn-shadow\"\n    >\n      Submit\n    </button>\n  </div>\n</div>\n",
                styles: [".action-btn{padding:12px 27px;border-radius:30px}.module-card{box-shadow:0 1px 14px 0 rgba(0,0,0,.1)!important;transition:all .9s ease;border-radius:15px!important;background:var(--background-color)}.field-height{height:48px;border-radius:30px;border:1px solid var(--border-color);background-color:var(--background-color);color:var(--text-color)!important;transition:all .6s ease!important}"]
            },] }
];
ValidateTellerPinComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] },
    { type: FormBuilder }
];

const ɵ0$1 = (toast) => {
    toast.addEventListener('mouseenter', Swal.stopTimer);
    toast.addEventListener('mouseleave', Swal.resumeTimer);
};
const Toast$1 = Swal.mixin({
    toast: true,
    position: 'top-end',
    showConfirmButton: false,
    timer: 3000,
    timerProgressBar: true,
    didOpen: ɵ0$1,
});
class AddAffordabilityComponent {
    constructor(dialogRef, data, cdr, formBuilder, formService, dialog, spinner, interactionService) {
        this.dialogRef = dialogRef;
        this.data = data;
        this.cdr = cdr;
        this.formBuilder = formBuilder;
        this.formService = formService;
        this.dialog = dialog;
        this.spinner = spinner;
        this.interactionService = interactionService;
        this.Form = this.formBuilder.group({});
        if (localStorage.getItem('dictionaries')) {
            this.dictionary = JSON.parse(localStorage.getItem('dictionaries'));
            this.cdr.markForCheck();
        }
        this.formAttributes = data['settings']['attributes'];
        this.formEndpoint = data['settings']['endpoint'];
    }
    ngOnInit() {
        this.getButton();
        this.initializeFormBuilder();
    }
    getButton() {
        this.formButton = this.formAttributes.find((item) => item.type === 'button');
        this.cdr.markForCheck();
    }
    initializeFormBuilder() {
        if (this.formAttributes.length) {
            const formObject = {};
            this.formAttributes.forEach((field) => {
                if (field.type !== 'button') {
                    if (field.validate.required) {
                        // tslint:disable-next-line: max-line-length
                        formObject[field.propertyname] = new FormControl('', [
                            Validators.required,
                            Validators.minLength(field.validate.minLength),
                            Validators.maxLength(field.validate.maxLength),
                        ]);
                    }
                    else {
                        formObject[field.propertyname] = new FormControl('');
                    }
                }
            });
            this.Form = new FormGroup(formObject);
            console.log(this.Form);
        }
    }
    submit() {
        if (this.Form.valid) {
            this.confirmSubmission();
        }
        else {
            this.Form.markAllAsTouched();
        }
    }
    uploadFile(event, propertyname) {
        let reader = new FileReader();
        if (event.target.files.length) {
            let file = event.target.files[0];
            if (file.size / 1024 / 1024 > 3) {
                Toast$1.fire({
                    icon: 'error',
                    title: 'File should not be greater than 3MB',
                });
                this.Form.get(propertyname).setValidators([Validators.maxLength(3)]);
                return;
            }
            else {
                this.Form.get(propertyname).clearValidators();
                this.Form.get(propertyname).updateValueAndValidity();
            }
            reader.readAsDataURL(file);
            reader.onload = () => {
                this.filename = file.name;
                this.Form.get('attachmentbase64').setValue(reader.result.split(',')[1]);
                this.Form.addControl('attachmentformat', new FormControl(file.type));
            };
        }
        console.log(this.Form);
    }
    confirmSubmission() {
        const dialogConfig = new MatDialogConfig();
        dialogConfig.height = '200px';
        dialogConfig.width = '500px';
        dialogConfig.panelClass = 'confirmPinAccountDialog';
        const response = this.dialog.open(ConfirmDialogComponent, dialogConfig);
        response.afterClosed().subscribe((result) => {
            if (result === 'true') {
                this.initializeSubmission();
            }
            else {
                return;
            }
        });
    }
    initializeSubmission() {
        this.interactionService.loadMessage('Submitting Data...');
        this.spinner.show();
        const _uuid = v4();
        const form = this.Form.value;
        const requestBody = this.formButton['request_body'].split(',');
        let params = {};
        for (const req of requestBody) {
            params[req] = form[req];
        }
        console.log(params);
        const sub = this.formService
            .post(this.formEndpoint, params, _uuid)
            .subscribe((response) => {
            if (response) {
                if (response['code'] == '200') {
                    this.spinner.hide();
                    this.Form.reset();
                    this.filename = '';
                    this.dialogRef.close({ response: 'success' });
                    Toast$1.fire({
                        icon: 'success',
                        title: 'Loan Affordability Submission Successful',
                    });
                }
                else {
                    this.spinner.hide();
                    Toast$1.fire({
                        icon: 'error',
                        title: response['data'],
                    });
                }
            }
            else {
                this.spinner.hide();
                Toast$1.fire({
                    icon: 'error',
                    title: 'Failed',
                });
            }
            sub.unsubscribe();
            this.spinner.hide();
        }, (error) => {
            sub.unsubscribe();
            this.spinner.hide();
            Toast$1.fire({
                icon: 'error',
                title: error['error']['error_description'],
            });
        });
    }
    getEmployerId() {
        let name = '';
        let partner;
        if (this.Form.value.employername) {
            name = this.Form.value.employername;
        }
        partner = this.dictionary['partner_institutions'].find((partner) => partner.name === name);
        this.Form.get('employerid').setValue(partner.partnerid);
        console.log(this.Form);
    }
}
AddAffordabilityComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-add-affordability',
                template: "<div class=\"card card-custom module-card\">\n  <div class=\"card-header card-header-tabs-line\">\n    <div class=\"card-title\">\n      <h3 class=\"card-label main-title\" style=\"font-size: 14px\">{{ data.info?.name }}</h3>\n    </div>\n    <div class=\"card-toolbar\">\n      <button\n        [mat-dialog-close]=\"false\"\n        class=\"btn btn-icon btn-outline-danger\"\n      >\n        <i class=\"fas fa-times\"></i>\n      </button>\n    </div>\n  </div>\n  <div class=\"card-body\">\n    <form [formGroup]=\"Form\">\n      <div class=\"container-fluid\" *ngIf=\"formAttributes\">\n        <div class=\"row\">\n          <div class=\"col-12\" *ngFor=\"let field of formAttributes\">\n            <div [ngSwitch]=\"field.type\">\n              <div *ngSwitchCase=\"'text'\">\n                <ng-container\n                  *ngIf=\"field.propertyname === 'employeeid'; else elseEmployee\"\n                >\n                  <div class=\"form-group\">\n                    <label>\n                      <ng-container\n                        *ngIf=\"\n                          Form.get('employername').value === 'GHANA_POLICE';\n                          else elsePoliceField\n                        \"\n                      >\n                        Payroll No\n                      </ng-container>\n                      <ng-template #elsePoliceField> Employee ID </ng-template>\n                      <span class=\"text-danger\" *ngIf=\"field.validate.required\"\n                        >*</span\n                      ></label\n                    >\n                    <input\n                      [hidden]=\"field.hidden\"\n                      *ngIf=\"Form.get(field.propertyname)\"\n                      [class.is-invalid]=\"\n                        Form.get(field.propertyname).touched &&\n                        Form.get(field.propertyname).invalid\n                      \"\n                      type=\"text\"\n                      class=\"form-control field-height\"\n                      placeholder=\"Enter Value\"\n                      [formControlName]=\"field.propertyname\"\n                    />\n                    <div\n                      class=\"invalid-feedback\"\n                      *ngIf=\"Form.get(field.propertyname)\"\n                    >\n                      <span\n                        *ngIf=\"Form.get(field.propertyname).errors?.required\"\n                        >{{ field.validate?.errorText }}</span\n                      >\n                    </div>\n                  </div>\n                </ng-container>\n                <ng-template #elseEmployee>\n                  <div class=\"form-group\">\n                    <label [hidden]=\"field.hidden\"\n                      >{{ field.label }}\n                      <span class=\"text-danger\" *ngIf=\"field.validate.required\"\n                        >*</span\n                      ></label\n                    >\n                    <input\n                      [hidden]=\"field.hidden\"\n                      *ngIf=\"Form.get(field.propertyname)\"\n                      [class.is-invalid]=\"\n                        Form.get(field.propertyname).touched &&\n                        Form.get(field.propertyname).invalid\n                      \"\n                      type=\"text\"\n                      class=\"form-control field-height\"\n                      [placeholder]=\"field.placeholder\"\n                      [formControlName]=\"field.propertyname\"\n                    />\n                    <div\n                      class=\"invalid-feedback\"\n                      *ngIf=\"Form.get(field.propertyname)\"\n                    >\n                      <span\n                        *ngIf=\"Form.get(field.propertyname).errors?.required\"\n                        >{{ field.validate?.errorText }}</span\n                      >\n                    </div>\n                  </div>\n                </ng-template>\n              </div>\n              <div *ngSwitchCase=\"'select'\">\n                <ng-container\n                  *ngIf=\"field.label === 'SELECT RANK'; else elseSelect\"\n                >\n                  <div\n                    class=\"form-group\"\n                    *ngIf=\"\n                      Form.get(field.conditional.when).value ===\n                      field.conditional.eq\n                    \"\n                  >\n                    <label for=\"exampleSelect1\"\n                      >{{ field.label }}\n                      </label\n                    >\n                    <select\n                      *ngIf=\"Form.get(field.propertyname)\"\n                      [class.is-invalid]=\"\n                        Form.get(field.propertyname).touched &&\n                        Form.get(field.propertyname).invalid\n                      \"\n                      class=\"form-control field-height\"\n                      id=\"exampleSelect1\"\n                      [formControlName]=\"field.propertyname\"\n                      (change)=\"getEmployerId()\"\n                    >\n                      <ng-container\n                      >\n                        <option\n                          *ngFor=\"let item of dictionary.partner_institutions\"\n                          [value]=\"item.name\"\n                        >\n                          {{ item.name }}\n                        </option>\n                      </ng-container>\n                    </select>\n                    <div\n                      class=\"invalid-feedback\"\n                      *ngIf=\"Form.get(field.propertyname)\"\n                    >\n                      <span\n                        *ngIf=\"Form.get(field.propertyname).errors?.required\"\n                        >{{ field.validate?.errorText }}</span\n                      >\n                    </div>\n                  </div>\n                </ng-container>\n                <ng-template #elseSelect>\n                  <div class=\"form-group\">\n                    <label for=\"exampleSelect1\"\n                      >{{ field.label }}\n                      <span *ngIf=\"field.validate.required\" class=\"text-danger\"\n                        >*</span\n                      ></label\n                    >\n                    <select\n                      *ngIf=\"Form.get(field.propertyname)\"\n                      [class.is-invalid]=\"\n                        Form.get(field.propertyname).touched &&\n                        Form.get(field.propertyname).invalid\n                      \"\n                      class=\"form-control field-height\"\n                      id=\"exampleSelect1\"\n                      [formControlName]=\"field.propertyname\"\n                      (change)=\"getEmployerId()\"\n                    >\n                      <ng-container\n                        *ngIf=\"field.data.datasource === 'partner_institutions'\"\n                      >\n                        <option\n                          *ngFor=\"let item of dictionary.partner_institutions\"\n                          [value]=\"item.name\"\n                        >\n                          {{ item.name }}\n                        </option>\n                      </ng-container>\n                    </select>\n                    <div\n                      class=\"invalid-feedback\"\n                      *ngIf=\"Form.get(field.propertyname)\"\n                    >\n                      <span\n                        *ngIf=\"Form.get(field.propertyname).errors?.required\"\n                        >{{ field.validate?.errorText }}</span\n                      >\n                    </div>\n                  </div>\n                </ng-template>\n              </div>\n              <div *ngSwitchCase=\"'file'\">\n                <div class=\"form-group\">\n                  <label>{{ field.label }}</label>\n                  <div></div>\n                  <div class=\"custom-file\">\n                    <input\n                      accept=\"image/jpeg, image/jpg, image/png, application/pdf\"\n                      (change)=\"uploadFile($event, field.propertyname)\"\n                      *ngIf=\"Form.get(field.propertyname)\"\n                      [class.is-invalid]=\"\n                        Form.get(field.propertyname).touched &&\n                        Form.get(field.propertyname).invalid\n                      \"\n                      type=\"file\"\n                      class=\"custom-file-input field-height\"\n                      id=\"customFile\"\n                    />\n                    <label class=\"custom-file-label\" for=\"customFile\"\n                      >{{ filename ? filename : \"choose file\" }}\n                    </label>\n                  </div>\n                  <span class=\"form-text text-muted\"\n                    >File should not be greater than 3MB.</span\n                  >\n                  <div\n                    class=\"invalid-feedback\"\n                    *ngIf=\"Form.get(field.propertyname)\"\n                  >\n                    <span\n                      *ngIf=\"Form.get(field.propertyname).errors?.required\"\n                      >{{ field.validate?.errorText }}</span\n                    >\n                  </div>\n                </div>\n              </div>\n            </div>\n          </div>\n        </div>\n      </div>\n    </form>\n  </div>\n  <div class=\"card-footer d-flex justify-content-end\">\n    <a\n      class=\"btn btn-danger font-weight-bold mr-3 action-btn btn-shadow\"\n      [mat-dialog-close]=\"false\"\n      >Cancel</a\n    >\n    <button\n      (click)=\"submit()\"\n      class=\"btn btn-success font-weight-light action-btn btn-shadow\"\n    >\n      Submit\n    </button>\n  </div>\n</div>\n",
                styles: [".field-height{height:48px;border-radius:30px;border:1px solid var(--border-color);color:var(--text-color)!important}.field-height,.module-card{background-color:var(--background-color);transition:all .6s ease!important}.module-card{box-shadow:0 1px 20px 0 rgba(0,0,0,.1)!important;border-radius:13px}.action-btn,.close-btn{padding:12px 25px;border-radius:35px}label{color:var(--text-color)}"]
            },] }
];
AddAffordabilityComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] },
    { type: ChangeDetectorRef },
    { type: FormBuilder },
    { type: FormsService },
    { type: MatDialog },
    { type: NgxSpinnerService },
    { type: InteractionService }
];

class WebcamDialogComponent {
    constructor(dialogRef, data, cdr) {
        this.dialogRef = dialogRef;
        this.cdr = cdr;
        this.pictureTaken = new EventEmitter();
        // toggle webcam on/off
        this.showWebcam = true;
        this.allowCameraSwitch = true;
        this.multipleWebcamsAvailable = false;
        this.videoOptions = {
        // width: {ideal: 1024},
        // height: {ideal: 576}
        };
        this.errors = [];
        // webcam snapshot trigger
        this.trigger = new Subject();
        // switch to next / previous / specific webcam; true/false: forward/backwards, string: deviceId
        this.nextWebcam = new Subject();
        this.key = data.key;
    }
    ngOnInit() {
        WebcamUtil.getAvailableVideoInputs().then((mediaDevices) => {
            this.multipleWebcamsAvailable = mediaDevices && mediaDevices.length > 1;
        });
    }
    ngAfterViewInit() {
        //Called after ngAfterContentInit when the component's view has been initialized. Applies to components only.
        //Add 'implements AfterViewInit' to the class.
    }
    triggerSnapshot() {
        this.trigger.next();
    }
    toggleWebcam() {
        this.showWebcam = !this.showWebcam;
    }
    handleInitError(error) {
        this.errors.push(error);
    }
    showNextWebcam(directionOrDeviceId) {
        // true => move forward through devices
        // false => move backwards through devices
        // string => move to device with given deviceId
        this.nextWebcam.next(directionOrDeviceId);
    }
    handleImage(webcamImage) {
        console.info('received webcam image', webcamImage);
        this.capturedImage = webcamImage;
        this.pictureTaken.emit(webcamImage);
        this.cdr.markForCheck();
    }
    cameraWasSwitched(deviceId) {
        console.log('active device: ' + deviceId);
        this.deviceId = deviceId;
    }
    get triggerObservable() {
        return this.trigger.asObservable();
    }
    get nextWebcamObservable() {
        return this.nextWebcam.asObservable();
    }
    close() {
        this.dialogRef.close('false');
    }
    save() {
        this.dialogRef.close({
            type: this.key,
            image: this.capturedImage.imageAsDataUrl,
            base64: this.capturedImage.imageAsBase64,
            imagetype: this.capturedImage._mimeType,
        });
    }
    removeSnapshot() {
        this.capturedImage = null;
        this.cdr.markForCheck();
    }
}
WebcamDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'kt-webcam-dialog',
                template: "<div class=\"card card-custom mb-0\">\n  <div class=\"card-header\">\n    <div class=\"card-title\">\n      <h3 class=\"card-label\" style=\"padding: 11px; font-size: 17px\">\n        <i class=\"flaticon-photo-camera mr-2\"></i>\n        WEBCAM\n      </h3>\n    </div>\n  </div>\n  <div class=\"card-body\" style=\"padding: 25px 40px\">\n    <mat-dialog-content>\n      <div class=\"row\">\n        <div class=\"col-md-6\">\n          <webcam\n            [height]=\"180\"\n            [width]=\"300\"\n            [trigger]=\"triggerObservable\"\n            (imageCapture)=\"handleImage($event)\"\n            *ngIf=\"showWebcam\"\n            [allowCameraSwitch]=\"allowCameraSwitch\"\n            [switchCamera]=\"nextWebcamObservable\"\n            [videoOptions]=\"videoOptions\"\n            (cameraSwitched)=\"cameraWasSwitched($event)\"\n            (initError)=\"handleInitError($event)\"\n          ></webcam>\n\n          <div class=\"d-flex mt-4\">\n            <a\n              (click)=\"triggerSnapshot()\"\n              class=\"btn btn-text-dark-50 btn-icon-primary font-weight-bold btn-hover-bg-light mr-3\"\n            >\n              <i class=\"flaticon2-files-and-folders\"></i> Take Snapshot\n            </a>\n            <a\n              (click)=\"removeSnapshot()\"\n              class=\"btn btn-text-dark-50 btn-icon-danger font-weight-bold btn-hover-bg-light mr-3\"\n            >\n              <i class=\"flaticon2-rubbish-bin\"></i> Remove Snapshot\n            </a>\n          </div>\n        </div>\n        <div class=\"col-6\">\n          <img\n            [src]=\"capturedImage.imageAsDataUrl\"\n            alt=\"captured image\"\n            class=\"img-thumbnail rounded img-fluid\"\n            *ngIf=\"capturedImage\"\n          />\n          <img\n            src=\"assets/default/placeholder-image.png\"\n            alt=\"...\"\n            class=\"img-thumbnail rounded img-fluid\"\n            *ngIf=\"!capturedImage\"\n          />\n          <span\n            class=\"d-block mt-4 text-center font-italic font-weight-bold\"\n            *ngIf=\"capturedImage\"\n            >IMAGE PREVIEW</span\n          >\n          <span\n            class=\"d-block mt-4 text-center font-italic font-weight-bold\"\n            *ngIf=\"!capturedImage\"\n            >NO IMAGE CAPTURED</span\n          >\n        </div>\n      </div>\n    </mat-dialog-content>\n  </div>\n  <div class=\"card-footer\">\n    <div mat-dialog-actions style=\"padding: 11px\" align=\"end\">\n      <button\n        (click)=\"close()\"\n        class=\"btn btn-outline-secondary font-weight-bold mx-2 px-4 py-3\"\n      >\n        Cancel\n      </button>\n      <button\n        (click)=\"save()\"\n        class=\"btn btn-light-primary font-weight-bold mx-2 px-4 py-3\"\n      >\n        Save Image\n      </button>\n    </div>\n  </div>\n</div>\n",
                styles: [".actionBtn{font-size:4em;cursor:pointer}.snapshot{text-align:center}.snapshot img{max-width:800px;max-height:800px}"]
            },] }
];
WebcamDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] },
    { type: ChangeDetectorRef }
];
WebcamDialogComponent.propDecorators = {
    pictureTaken: [{ type: Output }]
};

class ViewMapDialogComponent {
    constructor(data, cdr) {
        this.data = data;
        this.cdr = cdr;
        this.lat = 0;
        this.lng = 0;
    }
    ngOnInit() {
        this.lat = this.data.latitude;
        this.lng = this.data.longitude;
        this.cdr.markForCheck();
        console.log(this.lat, this.lng);
    }
}
ViewMapDialogComponent.decorators = [
    { type: Component, args: [{
                selector: "kt-view-map-dialog",
                template: "<h1 mat-dialog-title style=\"padding: 11px; font-size: 17px\">\n  View Location Address\n</h1>\n<mat-divider></mat-divider>\n<div mat-dialog-content style=\"padding: 5px 40px\">\n  <agm-map [latitude]=\"lat\" [longitude]=\"lng\">\n    <agm-marker [latitude]=\"lat\" [longitude]=\"lng\"></agm-marker>\n  </agm-map>\n</div>\n<mat-divider></mat-divider>\n<div mat-dialog-actions style=\"padding: 11px\" align=\"end\">\n  <button mat-button mat-dialog-close>Close</button>\n</div>\n",
                styles: ["agm-map{height:300px!important}"]
            },] }
];
ViewMapDialogComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] },
    { type: ChangeDetectorRef }
];

const ɵ0 = (toast) => {
    toast.addEventListener('mouseenter', Swal.stopTimer);
    toast.addEventListener('mouseleave', Swal.resumeTimer);
};
const Toast = Swal.mixin({
    toast: true,
    position: 'top-end',
    showConfirmButton: false,
    timer: 3000,
    timerProgressBar: true,
    didOpen: ɵ0,
});
class OtpValidationDialogComponent {
    constructor(dialogRef, messagingService, data, formBuilder, spinner, cdr) {
        this.dialogRef = dialogRef;
        this.messagingService = messagingService;
        this.data = data;
        this.formBuilder = formBuilder;
        this.spinner = spinner;
        this.cdr = cdr;
        this.phonenumber = data.phone;
        this.hash = data.hash;
        this.customerDetails = data.customerdetails;
        this.Form = this.formBuilder.group({
            pin: ['', [Validators.required, Validators.maxLength(6)]],
        });
    }
    ngOnInit() { }
    confirm() {
        console.log(this.Form);
        if (this.Form.valid) {
            this.validateOTP();
        }
        else {
            this.Form.markAllAsTouched();
        }
    }
    validateOTP() {
        bcrypt.compare(this.Form.get('pin').value, this.hash, (err, result) => {
            if (result == true) {
                console.log(result);
                this.dialogRef.close({ confirm: true });
                this.cdr.markForCheck();
            }
            else if (err) {
                console.log(err);
                this.alertWithError('OTP', err);
                this.cdr.markForCheck();
            }
            else {
                console.log(result);
                this.alertWithError('OTP', 'PIN ENTERED IS INVALID');
                this.cdr.markForCheck();
            }
        });
    }
    close() {
        this.dialogRef.close();
    }
    alertWithError(title, message) {
        Swal.fire({
            icon: 'error',
            title: title,
            text: message,
        });
    }
    resend_otp() {
        this.loadingMessage = 'SENDING OTP SMS FOR VERIFICATION, PLEASE WAIT...';
        this.spinner.show();
        const _uuid = v4();
        const postbody = {
            email: this.customerDetails.email,
            phonenumber: this.customerDetails.phonenumber,
        };
        const sub = this.messagingService.sendOTPSMS(postbody, _uuid).subscribe((response) => {
            if (response) {
                Toast.fire({
                    icon: 'success',
                    title: 'AN SMS WITH A PIN IS SENT TO YOUR NUMBER',
                });
                this.hash = response['otp'];
                this.spinner.hide();
                this.cdr.markForCheck();
                sub.unsubscribe();
            }
        }, (error) => {
            console.log(error['error']['text'], 'otp error');
            this.spinner.hide();
            this.cdr.markForCheck();
            sub.unsubscribe();
        });
    }
}
OtpValidationDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'kt-otp-validation-dialog',
                template: "<ngx-spinner\n  bdColor=\"rgba(0,0,0,0.6)\"\n  size=\"medium\"\n  color=\"#fff\"\n  type=\"ball-clip-rotate-pulse\"\n>\n<p class=\"text-uppercase\" style=\"font-size: 12px; color: white\">{{ loadingMessage }}</p>\n</ngx-spinner>\n<div class=\"card card-custom gutter-b m-0\">\n  <div class=\"card-body\">\n    <div class=\"row mb-3\">\n      <div class=\"col-12 text-center\">\n        <span class=\"svg-icon svg-icon-primary svg-icon-3x mb-3\"\n          ><!--begin::Svg Icon | path:C:\\wamp64\\www\\keenthemes\\themes\\metronic\\theme\\html\\demo1\\dist/../src/media/svg/icons\\General\\Unlock.svg--><svg\n            xmlns=\"http://www.w3.org/2000/svg\"\n            xmlns:xlink=\"http://www.w3.org/1999/xlink\"\n            width=\"24px\"\n            height=\"24px\"\n            viewBox=\"0 0 24 24\"\n            version=\"1.1\"\n          >\n            <g stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\">\n              <mask fill=\"white\">\n                <use xlink:href=\"#path-1\" />\n              </mask>\n              <g />\n              <path\n                d=\"M15.6274517,4.55882251 L14.4693753,6.2959371 C13.9280401,5.51296885 13.0239252,5 12,5 C10.3431458,5 9,6.34314575 9,8 L9,10 L14,10 L17,10 L18,10 C19.1045695,10 20,10.8954305 20,12 L20,18 C20,19.1045695 19.1045695,20 18,20 L6,20 C4.8954305,20 4,19.1045695 4,18 L4,12 C4,10.8954305 4.8954305,10 6,10 L7,10 L7,8 C7,5.23857625 9.23857625,3 12,3 C13.4280904,3 14.7163444,3.59871093 15.6274517,4.55882251 Z\"\n                fill=\"#000000\"\n              />\n            </g></svg\n          ><!--end::Svg Icon--></span\n        >\n        <h6 class=\"font-weight-bold\">OTP PIN VERIFICATION</h6>\n      </div>\n    </div>\n\n    <mat-dialog-content>\n      <h6 class=\"font-weight-bold mb-3\">\n        We have sent you an SMS with a validation PIN to {{ phonenumber }}\n      </h6>\n\n      <form [formGroup]=\"Form\" novalidate>\n        <div class=\"form-group mt-3\">\n          <label class=\"text-muted font-weight-light\">ENTER PIN</label>\n          <input\n            [class.is-invalid]=\"\n              Form.get('pin').touched && Form.get('pin').invalid\n            \"\n            type=\"text\"\n            formControlName=\"pin\"\n            class=\"form-control custom-input\"\n            placeholder=\"Enter pin\"\n          />\n          <div class=\"invalid-feedback\">\n            <span *ngIf=\"Form.get('pin').hasError('required')\"\n              >Enter your pin verify</span\n            >\n            <span *ngIf=\"Form.get('pin').hasError('maxlength')\"\n              >Maximum length of the pin must be 6</span\n            >\n          </div>\n        </div>\n      </form>\n    </mat-dialog-content>\n\n    <div class=\"text-center\">\n      <a\n        style=\"padding: 10px 20px\"\n        (click)=\"resend_otp()\"\n        class=\"btn btn-text-dark-50 btn-icon-primary font-weight-light btn-hover-bg-light mt-3 mr-3\"\n      >\n        <i class=\"fas fa-redo\" style=\"font-size: 12px\"></i> RESEND OTP\n      </a>\n      <a\n        style=\"padding: 10px 20px\"\n        (click)=\"close()\"\n        class=\"btn btn-text-dark-50 btn-icon-danger font-weight-light btn-hover-bg-light mr-3 mt-3\"\n      >\n        <i class=\"flaticon2-cancel-music\" style=\"font-size: 12px\"></i> CANCEL\n      </a>\n      <a\n        style=\"padding: 10px 20px\"\n        (click)=\"confirm()\"\n        class=\"btn btn-text-dark-50 btn-icon-primary font-weight-light btn-hover-bg-light mt-3\"\n      >\n        <i class=\"fas fa-check\" style=\"font-size: 12px\"></i> CONFIRM\n      </a>\n    </div>\n  </div>\n</div>\n",
                styles: [".custom-input{height:50px!important;border-radius:0!important;background:transparent;border-top:none;border-left:none;border-right:none}"]
            },] }
];
OtpValidationDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: MessagingService },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] },
    { type: FormBuilder },
    { type: NgxSpinnerService },
    { type: ChangeDetectorRef }
];

class PermissionfilterPipe {
    transform(permissions, term) {
        // check if search is undefined
        if (term === undefined)
            return permissions;
        // return updated user
        return permissions.filter((user) => {
            return user.modulename.toLowerCase().includes(term.toLowerCase());
        });
    }
}
PermissionfilterPipe.decorators = [
    { type: Pipe, args: [{
                name: 'permissionfilter',
            },] }
];

class LibCommonModule {
}
LibCommonModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    SignOutDialogComponent,
                    ModuleNotFoundComponent,
                    EditAccountProfileFormComponent,
                    ProfileDashboardComponent,
                    PermissionfilterPipe,
                    SearchResultComponent,
                    PdfViewerComponent,
                    PinConfirmationComponent,
                    MapLocationDialogComponent,
                    ValidateTellerPinComponent,
                    AddAffordabilityComponent,
                    WebcamDialogComponent,
                    ViewMapDialogComponent,
                    OtpValidationDialogComponent,
                    ConfirmDialogComponent,
                ],
                imports: [
                    MatTableModule,
                    MatInputModule,
                    MatPaginatorModule,
                    HttpClientModule,
                    CommonModule,
                    FormsModule,
                    ReactiveFormsModule,
                    MatTableExporterModule,
                    MatSelectModule,
                    NgbModule,
                    NgxIntlTelInputModule,
                    MatDialogModule,
                    PdfViewerModule,
                    ChartsModule,
                    AgmCoreModule.forRoot({
                        apiKey: 'AIzaSyBc-xUcz1gNs-AW45HLo8ZUn2_ig58RcZk',
                    }),
                    WebcamModule,
                    LibServicesModule,
                ],
                entryComponents: [
                    AddAffordabilityComponent,
                    WebcamDialogComponent,
                    ViewMapDialogComponent,
                    SignOutDialogComponent,
                    PdfViewerComponent,
                    PinConfirmationComponent,
                    ValidateTellerPinComponent,
                    OtpValidationDialogComponent,
                    ConfirmDialogComponent,
                ],
                exports: [
                    PdfViewerComponent,
                    ViewMapDialogComponent,
                    OtpValidationDialogComponent,
                    ConfirmDialogComponent,
                ],
                schemas: [CUSTOM_ELEMENTS_SCHEMA],
            },] }
];

/*
 * Public API Surface of lib-common
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AddAffordabilityComponent, ConfirmDialogComponent, EditAccountProfileFormComponent, LibCommonModule, MapLocationDialogComponent, ModuleNotFoundComponent, OtpValidationDialogComponent, PdfViewerComponent, PinConfirmationComponent, ProfileDashboardComponent, SearchResultComponent, SignOutDialogComponent, ValidateTellerPinComponent, ViewMapDialogComponent, WebcamDialogComponent, ɵ0$3 as ɵ0, PermissionfilterPipe as ɵa };
//# sourceMappingURL=interfaceft-icb-lib-common.js.map
